@@ -43,7 +43,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελός σας έχει <strong>τροποποιηθεί</strong>.",
     "No favorites" : "Δεν υπάρχουν αγαπημένα",
-    "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
     "Accept" : "Αποδοχή",
     "Reject" : "Απόρριψη",
     "Incoming ownership transfer from {user}" : "Εισερχόμενη μεταβίβαση κυριότητας από τον {user}",
@@ -58,8 +57,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Η μεταφορά κυριότητας του {path} στον {user} ολοκληρώθηκε.",
     "in %s" : "σε %s",
     "Transferred from %1$s on %2$s" : "Μεταβιβάστηκε από %1$s σε %2$s",
-    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
     "File Management" : "Διαχείριση αρχείων",
     "Home" : "Αρχική",
     "Target folder does not exist any more" : "Ο φάκελος προορισμού δεν υπάρχει πια",
@@ -83,6 +80,7 @@ OC.L10N.register(
     "Pending" : "Εκκρεμεί",
     "Clear filter" : "Εκκαθάριση φίλτρου",
     "Modified" : "Τροποποιήθηκε",
+    "Search everywhere" : "Αναζητήστε παντού",
     "Type" : "Τύπος",
     "Active filters" : "Ενεργά φίλτρα",
     "Remove filter" : "Αφαίρεση φίλτρου",
@@ -90,14 +88,11 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
     "Name" : "Όνομα",
     "Size" : "Μέγεθος",
-    "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
-    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
     "Actions" : "Ενέργειες",
     "List of files and folders." : "Λίστα αρχείων και φακέλων.",
     "Column headers with buttons are sortable." : "Οι επικεφαλίδες στηλών με κουμπιά είναι ταξινομήσιμες.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
     "File not found" : "Δε βρέθηκε το αρχείο",
-    "{count} selected" : "{count} έχουν επιλεγεί",
     "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{relative}% used" : "{relative}% χρησιμοποιείται",
@@ -108,6 +103,8 @@ OC.L10N.register(
     "Create new folder" : "Δημιουργία νέου φακέλου",
     "This name is already in use." : "Αυτό το όνομα χρησιμοποιείται ήδη.",
     "Create" : "Δημιουργία",
+    "Refresh" : "Ανανέωση",
+    "Limit" : "'Οριο",
     "Submit" : "Υποβολή",
     "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Transfer" : "Μεταφορά",
@@ -133,7 +130,6 @@ OC.L10N.register(
     "Error during upload: {message}" : "Σφάλμα κατά τη μεταφόρτωση: {message}",
     "Error during upload, status code {status}" : "Σφάλμα κατά τη μεταφόρτωση, κωδικός κατάστασης {status}",
     "Unknown error during upload" : "Άγνωστο σφάλμα κατά τη μεταφόρτωση",
-    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
     "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
     "Retry" : "Δοκιμή ξανά",
     "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
@@ -146,21 +142,29 @@ OC.L10N.register(
     "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
     "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
-    "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
+    "General" : "Γενικά",
+    "All files" : "Όλα τα αρχεία",
+    "Personal files" : "Προσωπικά αρχεία",
     "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
     "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
+    "Appearance" : "Εμφάνιση",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
-    "Enable the grid view" : "Ενεργοποίηση της προβολής πλέγματος",
     "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
     "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
-    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Εάν έχετε ενεργοποιήσει το 2FA, πρέπει να δημιουργήσετε και να χρησιμοποιήσετε έναν νέο κωδικό πρόσβασης εφαρμογής κάνοντας κλικ εδώ.",
+    "Copy" : "Αντιγραφή",
     "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
+    "File actions" : "Ενέργειες αρχείου",
+    "Rename" : "Μετονομασία",
+    "Delete" : "Διαγραφή",
+    "Manage tags" : "Διαχείριση ετικετών",
     "Selection" : "Επιλογή",
+    "Deselect all" : "Αναίρεση επιλογής όλων",
     "Navigation" : "Πλοήγηση",
     "View" : "Προβολή",
+    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
+    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
     "You" : "Εσύ",
     "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
     "Owner" : "Κάτοχος",
@@ -172,7 +176,6 @@ OC.L10N.register(
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
     "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
     "Creating file" : "Δημιουργία αρχείου",
-    "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
     "Leave this share" : "Αποχώρηση από αυτό το κοινόχρηστο",
     "Leave these shares" : "Αποχώρηση από αυτά τα κοινόχρηστα",
     "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
@@ -182,29 +185,27 @@ OC.L10N.register(
     "Delete files" : "Διαγραφή αρχείων",
     "Delete folder" : "Διαγραφή φακέλου",
     "Delete folders" : "Διαγραφή φακέλων",
-    "Delete" : "Διαγραφή",
     "Confirm deletion" : "Επιβεβαίωση διαγραφής",
     "Cancel" : "Ακύρωση",
+    "Download" : "Λήψη",
+    "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
+    "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
     "(copy)" : "(αντιγραφή)",
     "(copy %n)" : "(αντιγραφή %n)",
-    "Move cancelled" : "Μετακίνηση ακυρώθηκε",
     "A file or folder with that name already exists in this folder" : "Ένα αρχείο ή ένας φάκελος με αυτό το όνομα υπάρχει ήδη σε αυτόν το φάκελο",
     "The files are locked" : "Το αρχεία είναι κλειδωμένα",
     "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
     "Choose destination" : "Επιλέξτε προορισμό",
     "Copy to {target}" : "Αντιγραφή σε {target}",
-    "Copy" : "Αντιγραφή",
     "Move to {target}" : "Μετακίνηση σε {target}",
     "Move" : "Μετακίνηση",
     "Move or copy operation failed" : "Η λειτουργία μετακίνησης ή αντιγραφής απέτυχε",
     "Move or copy" : "Μετακίνηση ή αντιγραφή",
-    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
     "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
     "Open in Files" : "Άνοιγμα στα Αρχεία",
     "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
-    "Rename" : "Μετονομασία",
-    "Open details" : "Άνοιγμα λεπτομερειών",
+    "Details" : "Λεπτομέρειες",
     "View in folder" : "Προβολή στον φάκελο",
     "Today" : "Σήμερα",
     "Last 7 days" : "Τελευταίες 7 ημέρες",
@@ -214,7 +215,7 @@ OC.L10N.register(
     "Documents" : "Έγγραφα",
     "Presentations" : "Παρουσιάσεις",
     "Audio" : "Ήχος",
-    "Photos and images" : "Φωτογραφίες και εικόνες",
+    "Images" : "Εικόνες",
     "Videos" : "Βίντεο",
     "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
@@ -230,8 +231,10 @@ OC.L10N.register(
     "Files copied successfully" : "Τα αρχεία αντιγράφηκαν επιτυχώς",
     "Files moved successfully" : "Τα αρχεία μετακινήθηκαν επιτυχώς",
     "Upload cancelled" : "Η μεταφόρτωση ακυρώθηκε",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{newName}\" χρησιμοποιείται ήδη στον φάκελο \"{dir}\". Παρακαλώ επιλέξτε ένα διαφορετικό όνομα.",
+    "Could not rename \"{oldName}\"" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\"",
     "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
     "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
     "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
     "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
@@ -242,9 +245,7 @@ OC.L10N.register(
     "Filenames must not end with \"{extension}\"." : "Τα ονόματα αρχείων δεν πρέπει να τελειώνουν με \"{extension}\".",
     "No favorites yet" : "Κανένα αγαπημένο ακόμα",
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
-    "All files" : "Όλα τα αρχεία",
     "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
-    "Personal files" : "Προσωπικά αρχεία",
     "List of your files and folders that are not shared." : "Λίστα αρχείων και φακέλων που δεν είναι κοινόχρηστα.",
     "No personal files found" : "Δε βρέθηκαν προσωπικά αρχεία",
     "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
@@ -252,12 +253,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Λίστα των πρόσφατα τροποποιημένων αρχείων και φακέλων.",
     "No recently modified files" : "Δεν υπάρχουν πρόσφατα τροποποιημένα αρχεία",
     "Files and folders you recently modified will show up here." : "Εδώ θα εμφανίζονται τα αρχεία και οι φάκελοι που τροποποιήσατε πρόσφατα.",
+    "Search" : "Αναζήτηση",
     "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
     "Select all" : "Επιλογή όλων",
     "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
     "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
-    "Download" : "Λήψη",
     "Show list view" : "Προβολή λίστας",
     "Show grid view" : "Προβολή πλέγματος",
     "Close" : "Κλείσιμο",
@@ -282,12 +283,12 @@ OC.L10N.register(
     "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
     "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
-    "Details" : "Λεπτομέρειες",
     "Please select tag(s) to add to the selection" : "Επιλέξτε ετικέτα (ες) για προσθήκη στην επιλογή",
     "Apply tag(s) to selection" : "Εφαρμογή ετικετών στην επιλογή",
     "Select directory \"{dirName}\"" : "Επιλέξτε κατάλογο \"{dirName}\"",
     "Select file \"{fileName}\"" : "Επιλέξτε αρχείο \"{fileName}\"",
     "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
     "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
     "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
     "copy" : "αντιγραφή",
@@ -296,9 +297,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
     "{newName} already exists" : "Το {newName} υπάρχει ήδη",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Αδυναμία μετονομασίας του \"{fileName}\", το αρχείο δεν υπάρχει πια.",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
-    "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
     "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του αρχείου \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Αδυναμία δημιουργίας του αρχείου \"{file}\" επειδή υπάρχει ήδη",
     "Could not create folder \"{dir}\" because it already exists" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\" επειδή υπάρχει ήδη",
@@ -331,27 +329,31 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για άτομα που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
     "Path" : "Διαδρομή",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Αγαπημένα",
     "Copy direct link (only works for people who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για άτομα που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "Upload file" : "Μεταφόρτωση αρχείου",
-    "Not favorited" : "Δεν είναι αγαπημένο",
     "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
-    "Storage informations" : "Πληροφορίες αποθήκευσης",
-    "Choose file" : "Επιλέξτε αρχείο",
-    "Go to the previous folder" : "Μετάβαση στον προηγούμενο φάκελο",
-    "Open the files app settings" : "Ανοίξτε τις ρυθμίσεις της εφαρμογής αρχείων",
-    "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
-    "Edit file locally" : "Επεξεργασία αρχείου τοπικά",
-    "Create new templates folder" : "Δημιουργία νέου φακέλου προτύπων",
+    "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
+    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
+    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
+    "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
+    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων...",
+    "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
+    "Enable the grid view" : "Ενεργοποίηση της προβολής πλέγματος",
+    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
+    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Εάν έχετε ενεργοποιήσει το 2FA, πρέπει να δημιουργήσετε και να χρησιμοποιήσετε έναν νέο κωδικό πρόσβασης εφαρμογής κάνοντας κλικ εδώ.",
+    "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
+    "Move cancelled" : "Μετακίνηση ακυρώθηκε",
+    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
+    "Open details" : "Άνοιγμα λεπτομερειών",
+    "Photos and images" : "Φωτογραφίες και εικόνες",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
-    "List of favorites files and folders." : "Λίστα αγαπημένων αρχείων και φακέλων.",
     "Personal Files" : "Προσωπικά Αρχεία",
     "Text file" : "Αρχείο κειμένου",
-    "New text file.txt" : "Νέο αρχείο file.txt",
-    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων..."
+    "New text file.txt" : "Νέο αρχείο file.txt"
 },
 "nplurals=2; plural=(n != 1);");
