@@ -42,7 +42,7 @@ OC.L10N.register(
     "Files" : "Archivos",
     "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>.",
     "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>modificado</strong>.",
-    "Upload (max. %s)" : "Cargar (max. %s)",
+    "No favorites" : "No hay favoritos",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
     "Incoming ownership transfer from {user}" : "Transferencia de propiedad entrante de {user}.",
@@ -59,14 +59,12 @@ OC.L10N.register(
     "Target folder does not exist any more" : "La carpeta destino ya no existe",
     "Reload current directory" : "Recargar directorio actual.",
     "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\".",
-    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
     "Favorite" : "Favorito",
-    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente.",
-    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló.",
-    "Rename file" : "Renombrar archivo.",
     "Filename" : "Nombre de archivo",
     "Folder name" : "Nombre de la carpeta",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiaste el nombre de \"{oldName}\" a \"{newName}\".",
+    "Rename file" : "Renombrar archivo.",
+    "Folder" : "Carpeta",
     "Pending" : "Pendiente",
     "Clear filter" : "Borrar filtro",
     "Modified" : "Modificado",
@@ -77,22 +75,19 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Size" : "Tamaño",
     "Actions" : "Acciones",
-    "\"{displayName}\" failed on some elements " : "La acción \"{displayName}\" falló en algunos elementos.",
-    "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó correctamente.",
     "List of files and folders." : "Lista de archivos y carpetas. ",
+    "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados","{count} seleccionado"],
     "{usedQuotaByte} used" : "{usedQuotaByte} usados.",
     "{used} of {quota} used" : "{used} de {quota} usados",
     "{relative}% used" : "{relative}% usados.",
     "Could not refresh storage stats" : "No se pudo actualizar las estadísticas de almacenamiento.",
     "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
-    "Create" : "Crear",
     "New folder" : "Carpeta nueva",
     "Create new folder" : "Crear nueva carpeta",
+    "Create" : "Crear",
+    "Refresh" : "Actualizar",
+    "Limit" : "Límite",
     "Submit" : "Enviar",
-    "Transfer ownership of a file or folder" : "Transferir propiedad de un archivo o carpeta.",
-    "Choose file or folder to transfer" : "Selecciona un archivo o carpeta para transferir.",
-    "Change" : "Cambiar",
-    "New owner" : "Nuevo propietario.",
     "Choose a file or folder to transfer" : "Elige un archivo o carpeta para transferir.",
     "Transfer" : "Transferencia",
     "Transfer {path} to {userid}" : "Transferir {path} a {userid}.",
@@ -100,80 +95,94 @@ OC.L10N.register(
     "Unknown error" : "Se presentó un error desconocido",
     "Ownership transfer request sent" : "Solicitud de transferencia de propiedad enviada.",
     "Cannot transfer ownership of a file or folder you do not own" : "No se puede transferir la propiedad de un archivo o carpeta que no posees.",
+    "Transfer ownership of a file or folder" : "Transferir propiedad de un archivo o carpeta.",
+    "Choose file or folder to transfer" : "Selecciona un archivo o carpeta para transferir.",
+    "Change" : "Cambiar",
+    "New owner" : "Nuevo propietario.",
     "Select file or folder to link to" : "Seleccionar archivo o carpeta para enlazar.",
-    "New" : "Nuevo",
-    "Loading current folder" : "Cargando directorio actual.",
-    "Retry" : "Reintentar",
-    "No files in here" : "No hay archivos aquí",
-    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
-    "Go back" : "Regresar",
     "Shared by link" : "Compartido por liga",
     "Shared" : "Compartido",
     "Switch to list view" : "Cambiar a vista de lista",
     "Not enough free space" : "No cuentas con suficiente espacio libre",
     "Operation is blocked by access control" : "La operación está bloqueada por el control de acceso.",
+    "Loading current folder" : "Cargando directorio actual.",
+    "Retry" : "Reintentar",
+    "No files in here" : "No hay archivos aquí",
+    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
+    "Go back" : "Regresar",
     "Views" : "Vistas",
     "Files settings" : "Configuración de archivos.",
-    "File cannot be accessed" : "No se puede acceder al archivo.",
     "Open in files" : "Abrir en archivos",
+    "File cannot be accessed" : "No se puede acceder al archivo.",
+    "Clipboard is not available" : "El portapapeles no está disponible",
+    "General" : "General",
+    "All files" : "Todos los archivos",
     "Sort favorites first" : "Ordenar primero los favoritos.",
+    "Appearance" : "Apariencia",
     "Show hidden files" : "Mostrar archivos ocultos",
     "Crop image previews" : "Recortar vistas previas de imágenes.",
     "Additional settings" : "Configuraciones adicionales",
     "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "Copiar al portapapeles",
-    "Use this address to access your Files via WebDAV" : "Usa esta dirección para acceder a tus archivos a través de WebDAV.",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si has habilitado la autenticación de dos factores (2FA), debes crear y usar una nueva contraseña de aplicación haciendo clic aquí.",
-    "Clipboard is not available" : "El portapapeles no está disponible",
-    "WebDAV URL copied to clipboard" : "URL de WebDAV copiada al portapapeles.",
+    "Copy" : "Copiar",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "File actions" : "Acciones de archivo",
+    "Rename" : "Renombrar",
+    "Delete" : "Borrar",
+    "Manage tags" : "Gestionar etiquetas",
+    "Selection" : "Selección",
+    "Deselect all" : "Deseleccionar todo",
+    "Navigation" : "Navegación",
+    "View" : "Ver",
+    "Toggle grid view" : "Alternar vista en cuadrícula.",
+    "Error while loading the file data" : "Error al cargar los datos del archivo.",
     "Owner" : "Dueño",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Tags" : "Etiquetas",
-    "Unable to change the favourite state of the file" : "No se puede cambiar el estado de favorito del archivo.",
-    "Error while loading the file data" : "Error al cargar los datos del archivo.",
+    "Blank" : "En blanco",
+    "Unable to create new file from template" : "No se pudo crear un nuevo archivo a partir de la plantilla.",
     "Pick a template for {name}" : "Selecciona una plantilla para {name}.",
     "Create a new file with the selected template" : "Crea un archivo nuevo con la plantilla seleccionada.",
     "Creating file" : "Creando archivo.",
-    "Blank" : "En blanco",
-    "Unable to create new file from template" : "No se pudo crear un nuevo archivo a partir de la plantilla.",
-    "Delete permanently" : "Borrar permanentemente",
     "Leave this share" : "Salir de esta compartición.",
     "Disconnect storage" : "Desconectar almacenamiento",
+    "Delete permanently" : "Borrar permanentemente",
     "Delete file" : "Eliminar archivo",
     "Delete files" : "Eliminar archivos",
-    "Delete" : "Borrar",
     "Cancel" : "Cancelar",
-    "Failed to redirect to client" : "No se pudo redirigir al cliente.",
-    "Edit locally" : "Editar localmente.",
-    "Copy" : "Copiar",
+    "Download" : "Descargar",
     "Move" : "Mover",
     "Move or copy" : "Mover o copiar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}.",
-    "Rename" : "Renombrar",
-    "Open details" : "Abrir detalles.",
+    "Open locally" : "Abrir localmente",
+    "Failed to redirect to client" : "No se pudo redirigir al cliente.",
+    "Open file locally" : "Abrir archivo localmente",
+    "Details" : "Detalles",
     "View in folder" : "Ver en la carpeta",
     "Today" : "Hoy",
     "Documents" : "Documentos",
     "Audio" : "Audio",
+    "Images" : "Imágenes",
     "Videos" : "Videos",
     "Unable to initialize the templates directory" : "No se pudo inicializar el directorio de plantillas.",
     "Templates" : "Plantillas",
     "Some files could not be moved" : "Algunos archivos no se pudieron mover",
+    "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo cambiar el nombre de \"{oldName}\", ya no existe.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
+    "Could not rename \"{oldName}\"" : "No se pudo cambiar el nombre de \"{oldName}\".",
     "This operation is forbidden" : "Esta operación está prohibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
     "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
+    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "All files" : "Todos los archivos",
     "Recent" : "Reciente",
-    "You do not have permission to upload or create files here" : "No tienes permiso para cargar o crear archivos aquí.",
+    "Search" : "Buscar",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "File could not be found" : "No fue posible encontrar el archivo",
-    "Download" : "Descargar",
     "Show list view" : "Mostrar vista de lista",
     "Show grid view" : "Mostrar vista de cuadrícula",
     "Close" : "Cerrar",
@@ -192,14 +201,15 @@ OC.L10N.register(
     "Uploading that item is not supported" : "No se admite la carga de ese elemento.",
     "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
     "Choose target folder" : "Selecciona la carpeta de destino.",
+    "Edit locally" : "Editar localmente.",
     "Open" : "Abrir",
     "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
-    "Details" : "Detalles",
     "Please select tag(s) to add to the selection" : "Selecciona la(s) etiqueta(s) para agregar a la selección.",
     "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección.",
     "Select directory \"{dirName}\"" : "Selecciona el directorio \"{dirName}\".",
     "Select file \"{fileName}\"" : "Selecciona el archivo \"{fileName}\".",
     "Unable to determine date" : "No fue posible determinar la fecha",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
     "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
     "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
     "copy" : "copia",
@@ -208,9 +218,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
     "{newName} already exists" : "{newName} ya existe",
-    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
-    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
     "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
     "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
@@ -218,11 +225,11 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Ingresa más de dos caracteres para buscar en otras carpetas.",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
-    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
     "{dirs} and {files}" : "{dirs} y {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
+    "You do not have permission to upload or create files here" : "No tienes permiso para cargar o crear archivos aquí.",
     "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
+    "New" : "Nuevo",
     "New file/folder menu" : "Menú de archivo/carpeta nuevo.",
     "Select file range" : "Selecciona un rango de archivos.",
     "{used}%" : "{used}%",
@@ -240,27 +247,19 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con \"{filter}\".","coincide con \"{filter}\".","coincide con \"{filter}\"."],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Se ha copiado el enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta).",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favorited" : "Marcado como favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Upload file" : "Cargar archivo",
-    "Not favorited" : "No es un favorito",
     "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
-    "\"remote user\"" : "\"usuario remoto\"",
-    "{newName} already exists." : "{newName} ya existe.",
-    "Name cannot be empty" : "El nombre no puede estar en blanco",
-    "Another entry with the same name already exists" : "Ya existe otra entrada con el mismo nombre.",
-    "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo cambiar el nombre de \"{oldName}\", ya no existe.",
-    "Could not rename \"{oldName}\"" : "No se pudo cambiar el nombre de \"{oldName}\".",
-    "Storage informations" : "Información de almacenamiento.",
-    "Go to the previous folder" : "Ir a la carpeta anterior.",
-    "Open the files app settings" : "Abrir la configuración de la aplicación de archivos.",
-    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tengas permisos para verlo. Pide al remitente que lo comparta contigo.",
-    "Create new templates folder" : "Crear nueva carpeta de plantillas.",
-    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
-    "Toggle %1$s sublist" : "Alternar sublista de %1$s.",
+    "Upload (max. %s)" : "Cargar (max. %s)",
+    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente.",
+    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló.",
+    "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó correctamente.",
+    "WebDAV URL copied to clipboard" : "URL de WebDAV copiada al portapapeles.",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Use this address to access your Files via WebDAV" : "Usa esta dirección para acceder a tus archivos a través de WebDAV.",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si has habilitado la autenticación de dos factores (2FA), debes crear y usar una nueva contraseña de aplicación haciendo clic aquí.",
+    "Open details" : "Abrir detalles.",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt"
 },
