@@ -54,7 +54,6 @@ OC.L10N.register(
     "Favorite files" : "즐겨찾는 파일",
     "No favorites" : "즐겨찾는 항목 없음",
     "More favorites" : "즐겨찾기 더 불러오기",
-    "Upload (max. %s)" : "업로드(최대 %s)",
     "Accept" : "수락",
     "Reject" : "거절",
     "Incoming ownership transfer from {user}" : "{user}의 소유권 이전 요청",
@@ -69,10 +68,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{user}(으)로부터 {path}의 소유권을 받았습니다.",
     "in %s" : "%s",
     "Transferred from %1$s on %2$s" : "%2$s의 %1$s에서 전송됨",
-    "Files compatibility" : "파일 호환성",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "모든 클라이언트와 동기화 될 수 있게 제한된 파일이름을 허용하세요. 기본적으로 POSIX (예를 들어 Linux 혹은 macOS) 에서 유효한 모든 파일이름은 허용됩니다.",
-    "Enforce Windows compatibility" : "윈도우 호환성 준수",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "예약어나 특수 문자 사용 등 Windows 시스템에서 유효하지 않은 파일 이름이 차단됩니다. 그러나 대소문자 구분의 호환성을 강제하지는 않습니다.",
     "File Management" : "파일 관리",
     "Home" : "홈",
     "Target folder does not exist any more" : "대상 폴더가 더 이상 존재하지 않습니다",
@@ -100,6 +95,7 @@ OC.L10N.register(
     "Unknown date" : "알 수 없는 날짜",
     "Clear filter" : "필터 지우기",
     "Modified" : "수정됨",
+    "Search everywhere" : "모든 곳에서 찾기",
     "Type" : "종류",
     "Active filters" : "활성 필터",
     "Remove filter" : "필터 삭제",
@@ -107,9 +103,6 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "모든 파일 선택/선택해제",
     "Name" : "이름",
     "Size" : "크기",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" 일부 요소로 실패",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
-    "\"{displayName}\" action failed" : "\"{displayName}\" 작업을 실패함",
     "Actions" : "작업",
     "(selected)" : "(선택됨)",
     "List of files and folders." : "파일과 폴더의 목록",
@@ -117,7 +110,6 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "버튼이 있는 열 머리글은 정렬할 수 있습니다.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "성능 상의 이유로 목록을 전부 표시하지 않았습니다. 목록을 탐색하면 파일들이 표시됩니다.",
     "File not found" : "파일을 찾을 수 없음",
-    "{count} selected" : "{count}개 선택됨",
     "{usedQuotaByte} used" : "{usedQuotaByte} 사용",
     "{used} of {quota} used" : "{quota} 중 {used} 사용함",
     "{relative}% used" : "{relative}% 사용",
@@ -129,6 +121,7 @@ OC.L10N.register(
     "Create new folder" : "새 폴더 생성",
     "This name is already in use." : "이 이름은 이미 사용 중입니다.",
     "Create" : "생성",
+    "Refresh" : "새로 고침",
     "Fill template fields" : "양식 입력란 채우기",
     "Submitting fields …" : "항목 제출 중 ...",
     "Submit" : "제출",
@@ -166,7 +159,6 @@ OC.L10N.register(
     "Error during upload: {message}" : "업로드 오류: {message}",
     "Error during upload, status code {status}" : "업로드 중 오류 발생, 상태 코드 {status}",
     "Unknown error during upload" : "업로드 중 알 수 없는 오류 발생",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" 작업을 성공적으로 실행함",
     "Loading current folder" : "현재 폴더를 불러오는 중",
     "Retry" : "다시 시도",
     "No files in here" : "여기에 파일 없음",
@@ -179,41 +171,33 @@ OC.L10N.register(
     "File cannot be accessed" : "파일에 접근할 수 없음",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "파일을 찾을 수 없거나 볼 권한이 없습니다. 보낸 이에게 공유를 요청하세요.",
     "Clipboard is not available" : "클립보드를 사용할 수 없습니다.",
-    "WebDAV URL copied to clipboard" : "WebDAV URL이 클립보드에 복사됨",
+    "General" : "일반",
+    "All files" : "모든 파일",
+    "Personal files" : "개인 파일",
     "Sort favorites first" : "즐겨찾기를 처음에 나열",
     "Sort folders before files" : "폴더를 파일보다 먼저 정렬",
+    "Appearance" : "외형",
     "Show hidden files" : "숨김 파일 보이기",
     "Crop image previews" : "이미지 미리보기 확대",
-    "Enable the grid view" : "바둑판식 보기 활성화",
-    "Enable folder tree" : "폴더 트리 활성화",
     "Additional settings" : "고급 설정",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "클립보드로 복사",
-    "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하세요.",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2단계 인증을 활성화했다면, 이곳을 클릭해 새로운 앱 암호를 만들어 사용해야 합니다.",
+    "Copy" : "복사",
     "Keyboard shortcuts" : "키보드 단축키",
-    "Speed up your Files experience with these quick shortcuts." : "이 빠른 단축키를 사용하여 파일 사용 속도를 높이세요.",
-    "Open the actions menu for a file" : "파일 작업 메뉴 열기",
-    "Rename a file" : "파일 이름 바꾸기",
-    "Delete a file" : "파일 삭제",
-    "Favorite or remove a file from favorites" : "즐겨찾기에 파일 등록 또는 제거",
-    "Manage tags for a file" : "파일 태그 관리",
+    "Rename" : "이름 바꾸기",
+    "Delete" : "삭제",
+    "Manage tags" : "태그 관리하기",
     "Selection" : "선택",
     "Select all files" : "모든 파일 선택",
-    "Deselect all files" : "모든 파일 선택 해제",
-    "Select or deselect a file" : "파일 선택 또는 선택 해제",
-    "Select a range of files" : "파일 범위 선택",
+    "Deselect all" : "모두 선택 해제",
     "Navigation" : "탐색",
-    "Navigate to the parent folder" : "상위 폴더로 이동",
-    "Navigate to the file above" : "위 파일로 이동",
-    "Navigate to the file below" : "아래 파일로 이동",
-    "Navigate to the file on the left (in grid mode)" : "왼쪽 파일로 이동 (그리드 모드에서)",
-    "Navigate to the file on the right (in grid mode)" : "오른쪽 파일로 이동 (그리드 모드에서)",
     "View" : "보기",
-    "Toggle the grid view" : "바둑판식 보기 전환",
-    "Open the sidebar for a file" : "파일 사이드바 열기",
+    "Toggle grid view" : "그리드뷰 전환",
     "Show those shortcuts" : "다음 단축키 표시",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "모든 클라이언트와 동기화 될 수 있게 제한된 파일이름을 허용하세요. 기본적으로 POSIX (예를 들어 Linux 혹은 macOS) 에서 유효한 모든 파일이름은 허용됩니다.",
+    "Files compatibility" : "파일 호환성",
+    "Enforce Windows compatibility" : "윈도우 호환성 준수",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "예약어나 특수 문자 사용 등 Windows 시스템에서 유효하지 않은 파일 이름이 차단됩니다. 그러나 대소문자 구분의 호환성을 강제하지는 않습니다.",
     "You" : "당신",
     "Shared multiple times with different people" : "여러 사용자와 공유됨",
     "Error while loading the file data" : "파일 데이터를 불러오는 중 오류 발생",
@@ -232,7 +216,6 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "파일 변환에 실패함:{message}",
     "All files failed to be converted" : "모든 파일이 변환에 실패했습니다.",
     "Failed to convert files" : "파일 변환에 실패했습니다",
-    "Deletion cancelled" : "삭제가 취소됨",
     "Leave this share" : "이 공유에서 떠나기",
     "Leave these shares" : "이 공유에서 떠나기",
     "Disconnect storage" : "저장소 연결 해제",
@@ -243,38 +226,35 @@ OC.L10N.register(
     "Delete files" : "파일 삭제",
     "Delete folder" : "폴더 삭제",
     "Delete folders" : "폴더 삭제",
-    "Delete" : "삭제",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}개 항목을 영구적으로 삭제하려 합니다."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count}개 항목을 삭제하려 합니다."],
     "Confirm deletion" : "삭제 확인",
     "Cancel" : "취소",
+    "Download" : "다운로드",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 이동...",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 복사...",
+    "Destination is not a folder" : "대상이 폴더가 아닙니다.",
+    "This file/folder is already in that directory" : "이 파일/폴더가 이미 그 경로에 있습니다.",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "파일/폴더를 그 안이나 그 안의 폴더로 이동할 수 없습니다.",
     "(copy)" : "(복사)",
     "(copy %n)" : "(%n 복사)",
-    "Move cancelled" : "이동이 취소됨",
     "A file or folder with that name already exists in this folder" : "같은 이름을 사용하는 파일 또는 폴더가 이미 이 폴더에 있습니다.",
     "The files are locked" : "이 파일은 잠겼습니다",
     "The file does not exist anymore" : "파일이 더이상 존재하지 않습니다.",
     "Choose destination" : "목적지 선택",
     "Copy to {target}" : "{target}에 복사",
-    "Copy" : "복사",
     "Move to {target}" : "{target}에 이동",
     "Move" : "이동",
     "Move or copy operation failed" : "이동 또는 복사 작업에 실패함",
     "Move or copy" : "이동이나 복사",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"의 이동 또는 복사를 취소했습니다.",
-    "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
     "Open folder {displayName}" : "{displayName} 폴더 열기",
     "Open in Files" : "파일에서 열기",
+    "Open locally" : "로컬에서 열기",
+    "Failed to redirect to client" : "클라이언트로 리디렉션 하는데 실패함",
     "Open file locally" : "로컬에서 파일 열기",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "이제 이 파일이 당신의 기기에서 열려야 합니다. 그렇지 않다면, 데스크톱 앱이 설치되어 있는지 확인하세요.",
     "Retry and close" : "재시도 후 닫기",
-    "Failed to redirect to client" : "클라이언트로 리디렉션 하는데 실패함",
-    "Open locally" : "로컬에서 열기",
-    "Rename" : "이름 바꾸기",
-    "Open details" : "자세한 정보 열기",
+    "Details" : "자세한 정보",
     "View in folder" : "폴더에서 보기",
     "Today" : "오늘",
     "Last 7 days" : "지난 7일",
@@ -287,9 +267,8 @@ OC.L10N.register(
     "PDFs" : "PDF",
     "Folders" : "폴더",
     "Audio" : "오디오",
-    "Photos and images" : "사진과 이미지",
+    "Images" : "이미지",
     "Videos" : "동영상",
-    "New folder creation cancelled" : "새 폴더 생성 취소됨",
     "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
     "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
     "Create templates folder" : "템플릿 폴더 만들기",
@@ -310,8 +289,10 @@ OC.L10N.register(
     "Files moved successfully" : "파일을 성공적으로 이동함",
     "Conflicts resolution skipped" : "충돌 해결 건너뜀",
     "Upload cancelled" : "업로드가 취소됨",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\"(이)가 더이상 존재하지 않아 이름을 바꿀 수 없습니다.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" 이름이 \"{dir}\" 폴더에서 이미 사용 중입니다. 다른 이름을 고르세요.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\"의 이름을 바꿀 수 없음",
     "This operation is forbidden" : "이 작업이 금지됨",
-    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
     "Storage is temporarily not available" : "저장소를 일시적으로 사용할 수 없음",
     "Unexpected error: {error}" : "예상치 못한 오류: {error}",
     "_%n file_::_%n files_" : ["파일 %n개"],
@@ -324,10 +305,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "즐겨찾는 파일과 폴더의 목록",
     "No favorites yet" : "즐겨찾는 항목 없음",
     "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
-    "All files" : "모든 파일",
     "List of your files and folders." : "내 폴더와 파일의 목록",
-    "All folders" : "모든 폴더",
-    "Personal files" : "개인 파일",
     "List of your files and folders that are not shared." : "공유되지 않는 파일과 폴더의 목록",
     "No personal files found" : "개인 파일을 찾을 수 없음",
     "Files that are not shared will show up here." : "공유되지 않는 파일이 이곳에 나타납니다.",
@@ -335,12 +313,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "최근에 수정된 파일과 폴더의 목록",
     "No recently modified files" : "최근에 수정된 파일 없음",
     "Files and folders you recently modified will show up here." : "최근에 수정한 파일과 폴더가 이곳에 표시됩니다.",
+    "Search" : "검색",
     "No entries found in this folder" : "이 폴더에 항목 없음",
     "Select all" : "모두 선택",
     "Upload too large" : "업로드한 파일이 너무 큼",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
     "File could not be found" : "파일을 찾을 수 없음",
-    "Download" : "다운로드",
     "Show list view" : "리스트 보기",
     "Show grid view" : "바둑판식 보기",
     "Close" : "닫기",
@@ -365,12 +343,12 @@ OC.L10N.register(
     "Edit locally" : "로컬에서 편집",
     "Open" : "열기",
     "Could not load info for file \"{file}\"" : "파일 \"{file}\"의 정보를 가져올 수 없음",
-    "Details" : "자세한 정보",
     "Please select tag(s) to add to the selection" : "선택한 항목에 추가할 태그를 고르세요.",
     "Apply tag(s) to selection" : "선택한 항목에 태그 적용하기",
     "Select directory \"{dirName}\"" : "디렉터리 \"{dirName}\" 선택",
     "Select file \"{fileName}\"" : "파일 \"{fileName}\" 선택",
     "Unable to determine date" : "날짜를 결정할 수 없음",
+    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
     "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
     "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
     "copy" : "복사",
@@ -379,9 +357,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin}을(를) {destination}(으)로 복사함",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} 및 다른 파일 {nbfiles}개를 {destination}(으)로 복사함",
     "{newName} already exists" : "{newName}이(가) 이미 존재함",
-    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "폴더 \"{dir}\" 내에 파일 \"{targetName}\"이(가) 이미 있습니다. 다른 이름을 사용하십시오.",
-    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
     "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
     "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
     "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
@@ -414,33 +389,56 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "직접 링크를 복사했습니다. (이 파일 및 폴더에 접근할 수 있는 사람에게만 작동)",
     "Path" : "경로",
     "_%n byte_::_%n bytes_" : ["%n 바이트"],
-    "Favorited" : "즐겨찾기에 추가됨",
+    "Favored" : "선호함",
+    "Favor" : "선호",
     "Copy direct link (only works for people who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
     "Upload file" : "파일 업로드",
-    "Not favorited" : "즐겨찾기에 없음",
+    "Not favored" : "선호하지 않음",
     "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
-    "You don't have permission to upload or create files here." : "여기에 파일을 업로드하거나 만들 권한이 없습니다.",
-    "Storage informations" : "저장소 정보",
-    "Choose file" : "파일 선택",
-    "Go to the previous folder" : "이전 폴더로 이동",
-    "Open the files app settings" : "파일 앱 설정을 열기",
-    "Unable to change the favourite state of the file" : "파일의 즐겨찾기 상태를 변경할 수 없음",
-    "Edit file locally" : "로컬에서 파일 편집",
-    "Edit online" : "온라인으로 편집",
-    "Create new templates folder" : "새로운 템플릿 폴더 만들기",
+    "Upload (max. %s)" : "업로드(최대 %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" 작업을 성공적으로 실행함",
+    "\"{displayName}\" action failed" : "\"{displayName}\" 작업을 실패함",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" 일부 요소로 실패",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
+    "Submitting fields…" : "입력란 제출중...",
+    "Filter filenames…" : "파일 이름 필터...",
+    "WebDAV URL copied to clipboard" : "WebDAV URL이 클립보드에 복사됨",
+    "Enable the grid view" : "바둑판식 보기 활성화",
+    "Enable folder tree" : "폴더 트리 활성화",
+    "Copy to clipboard" : "클립보드로 복사",
+    "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하세요.",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2단계 인증을 활성화했다면, 이곳을 클릭해 새로운 앱 암호를 만들어 사용해야 합니다.",
+    "Deletion cancelled" : "삭제가 취소됨",
+    "Move cancelled" : "이동이 취소됨",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"의 이동 또는 복사를 취소했습니다.",
+    "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
+    "Open details" : "자세한 정보 열기",
+    "Photos and images" : "사진과 이미지",
+    "New folder creation cancelled" : "새 폴더 생성 취소됨",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount}개 폴더"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount}개 파일"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1개 파일과 {folderCount}개 폴더"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount}개 파일과 1개 폴더"],
     "{fileCount} files and {folderCount} folders" : "{fileCount}개 파일과 {folderCount}개 폴더",
-    "List of favorites files and folders." : "즐겨찾는 파일과 폴더의 목록",
+    "All folders" : "모든 폴더",
     "Personal Files" : "개인 파일",
     "Text file" : "텍스트 파일",
     "New text file.txt" : "새 텍스트 파일.txt",
-    "Favored" : "선호함",
-    "Favor" : "선호",
-    "Not favored" : "선호하지 않음",
-    "Submitting fields…" : "입력란 제출중...",
-    "Filter filenames…" : "파일 이름 필터..."
+    "Speed up your Files experience with these quick shortcuts." : "이 빠른 단축키를 사용하여 파일 사용 속도를 높이세요.",
+    "Open the actions menu for a file" : "파일 작업 메뉴 열기",
+    "Rename a file" : "파일 이름 바꾸기",
+    "Delete a file" : "파일 삭제",
+    "Favorite or remove a file from favorites" : "즐겨찾기에 파일 등록 또는 제거",
+    "Manage tags for a file" : "파일 태그 관리",
+    "Deselect all files" : "모든 파일 선택 해제",
+    "Select or deselect a file" : "파일 선택 또는 선택 해제",
+    "Select a range of files" : "파일 범위 선택",
+    "Navigate to the parent folder" : "상위 폴더로 이동",
+    "Navigate to the file above" : "위 파일로 이동",
+    "Navigate to the file below" : "아래 파일로 이동",
+    "Navigate to the file on the left (in grid mode)" : "왼쪽 파일로 이동 (그리드 모드에서)",
+    "Navigate to the file on the right (in grid mode)" : "오른쪽 파일로 이동 (그리드 모드에서)",
+    "Toggle the grid view" : "바둑판식 보기 전환",
+    "Open the sidebar for a file" : "파일 사이드바 열기"
 },
 "nplurals=1; plural=0;");
