@@ -101,7 +101,6 @@ OC.L10N.register(
     "Administration" : "Quản trị viên",
     "Users" : "Người dùng",
     "Additional settings" : "Cài đặt bổ sung",
-    "Artificial Intelligence" : "Trí tuệ nhân tạo",
     "Administration privileges" : "Đặc quyền quản trị",
     "Groupware" : "Phần mềm nhóm",
     "Overview" : "Tổng quan",
@@ -111,6 +110,7 @@ OC.L10N.register(
     "Calendar" : "Lịch",
     "Personal info" : "Thông tin cá nhân",
     "Mobile & desktop" : "Điện thoại di động và máy tính để bàn",
+    "Artificial Intelligence" : "Trí tuệ nhân tạo",
     "Email server" : "Máy chủ mail",
     "Background jobs" : "Các công việc trong nền",
     "Unlimited" : "Không giới hạn",
@@ -138,7 +138,6 @@ OC.L10N.register(
     "Profile information" : "Thông tin cá nhân",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Ảnh hồ sơ, tên đầy đủ, email, số điện thoại, địa chỉ, trang web, Twitter, tổ chức, vai trò, tiêu đề, tiểu sử và liệu hồ sơ của bạn có được bật hay không",
     "Nextcloud settings" : "Cài đặt Cloud",
-    "Task:" : "Tác vụ:",
     "Enable" : "Bật",
     "Machine translation" : "Dịch máy",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Dịch máy có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây, bạn có thể xác định mức độ ưu tiên của ứng dụng dịch máy mà bạn đã cài đặt vào lúc này.",
@@ -147,9 +146,10 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng tạo hình ảnh",
     "Text processing" : "Xử lý văn bản",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Các tác vụ xử lý mở rộng có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng cho tác vụ nào.",
+    "Task:" : "Tác vụ:",
     "Here you can decide which group can access certain sections of the administration settings." : "Tại đây bạn có thể quyết định nhóm nào có thể truy cập các phần nhất định của cài đặt quản trị.",
-    "None" : "Không gì cả",
     "Unable to modify setting" : "Không thể sửa đổi cài đặt",
+    "None" : "Không gì cả",
     "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
     "Allow resharing" : "Cho phép chia sẻ lại",
     "Allow sharing with groups" : "Cho phép chia sẻ với các nhóm",
@@ -179,6 +179,8 @@ OC.L10N.register(
     "Featured" : "Tính năng được trang bị",
     "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
+    "Disable all" : "Vô hiệu hóa tất cả",
+    "Download and enable all" : "Tải xuống và kích hoạt tất cả",
     "All apps are up-to-date." : "Tất cả ứng dụng được cập nhật.",
     "Icon" : "Biểu tượng",
     "Name" : "Tên",
@@ -187,20 +189,27 @@ OC.L10N.register(
     "Actions" : "Hành động",
     "Results from other categories" : "Kết quả từ các danh mục khác",
     "No apps found for your version" : "Không tìm thấy ứng dụng nào cho phiên bản của bạn",
-    "Disable all" : "Vô hiệu hóa tất cả",
-    "Download and enable all" : "Tải xuống và kích hoạt tất cả",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n ứng dụng có sẵn bản cập nhật"],
     "_Update_::_Update all_" : ["Cập nhật tất cả"],
+    "Failed to create group" : "Không tạo được nhóm",
+    "Create group" : "Tạo nhóm",
+    "Group name" : "Tên nhóm",
+    "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
     "Loading" : "Đang tải",
     "Type" : "Loại",
+    "Learn more" : "Đọc nhiều hơn",
+    "Confirm" : "Xác nhận",
+    "Cancel" : "Hủy",
     "Description" : "Mô tả",
-    "Details" : "Thông tin",
+    "View in store" : "Xem tại cửa hàng",
+    "Visit website" : "Truy cập trang web",
+    "Admin documentation" : "Tài liệu quản trị",
+    "Developer documentation" : "Tài liệu dành cho nhà phát triển",
+    "Details" : "Chi tiết",
     "All" : "Tất cả",
     "Limit app usage to groups" : "Giới hạn sử dụng ứng dụng cho các nhóm",
     "No results" : "Không có kết quả",
     "Update to {version}" : "Cập nhật tới {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ứng dụng này không thể được cài đặt vì các điều kiện phụ thuộc sau không được đáp ứng:",
     "Categories" : "Các hạng mục",
     "Resources" : "Các nguồn lực",
@@ -209,11 +218,11 @@ OC.L10N.register(
     "Request feature" : "Yêu cầu tính năng",
     "Ask questions or discuss" : "Hỏi các câu hỏi hoặc thảo luận",
     "Rate" : "Đánh giá",
-    "View in store" : "Xem tại cửa hàng",
-    "Visit website" : "Truy cập trang web",
-    "Admin documentation" : "Tài liệu quản trị",
-    "Developer documentation" : "Tài liệu dành cho nhà phát triển",
     "Changelog" : "Sổ cập nhập thay đổi",
+    "Google Chrome for Android" : "Google Chrome cho Android",
+    "{productName} iOS app" : "Ứng dụng iOS {productName}",
+    "{productName} Android app" : "Ứng dụng Android {productName}",
+    "This session" : "Phiên này",
     "Device name" : "Tên thiết bị",
     "Marked for remote wipe" : "Đánh dấu để xóa từ xa",
     "Device settings" : "Cài đặt thiết bị",
@@ -222,54 +231,52 @@ OC.L10N.register(
     "Revoke" : "Thu hồi",
     "Wipe device" : "Xóa thiết bị",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Việc thu hồi mã thông báo này có thể ngăn quá trình xóa thiết bị của bạn nếu thiết bị chưa bắt đầu quá trình xóa.",
-    "Google Chrome for Android" : "Google Chrome cho Android",
-    "{productName} iOS app" : "Ứng dụng iOS {productName}",
-    "{productName} Android app" : "Ứng dụng Android {productName}",
-    "This session" : "Phiên này",
     "Device" : "Thiết bị",
     "Last activity" : "Hoạt động cuối",
     "Devices & sessions" : "Thiết bị và phiên truy cập",
     "Web, desktop and mobile clients currently logged in to your account." : "Web, máy tính để bàn và máy khách di động hiện đang đăng nhập vào tài khoản của bạn.",
+    "Error while creating device token" : "Lỗi trong khi tạo mã thông báo thiết bị",
     "App name" : "Tên ứng dụng",
     "Create new app password" : "Tạo ứng dụng mật khẩu mới",
-    "Error while creating device token" : "Lỗi trong khi tạo mã thông báo thiết bị",
+    "Could not copy app password. Please copy it manually." : "Không thể sao chép ứng dụng mật khẩu. Vui lòng sao chép thủ công.",
     "Login" : "Đăng nhập",
     "Password" : "Mật khẩu",
     "Show QR code for mobile apps" : "Hiển thị mã QR cho ứng dụng di động",
-    "Could not copy app password. Please copy it manually." : "Không thể sao chép ứng dụng mật khẩu. Vui lòng sao chép thủ công.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Sử dụng dịch vụ cron hệ thống để gọi tệp cron.php cứ sau 5 phút.",
+    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Cần có phần mở rộng PHP POSIX. Xem {linkstart}tài liệu PHP{linkend} để biết thêm chi tiết.",
+    "Unable to update background job mode" : "Không thể cập nhật chế độ công việc nền",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Để máy chủ hoạt động bình thường, điều quan trọng là phải định cấu hình chính xác các công việc nền. Cron là cài đặt được đề xuất. Vui lòng xem tài liệu để biết thêm thông tin.",
     "Last job execution ran {time}. Something seems wrong." : "Lần thực hiện công việc cuối cùng đã diễn ra {time}. Có điều gì đó có vẻ không ổn.",
     "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
     "Background job did not run yet!" : "Công việc nền chưa chạy!",
     "Cron (Recommended)" : "Cron (Được khuyến nghị)",
-    "Use system cron service to call the cron.php file every 5 minutes." : "Sử dụng dịch vụ cron hệ thống để gọi tệp cron.php cứ sau 5 phút.",
-    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Cần có phần mở rộng PHP POSIX. Xem {linkstart}tài liệu PHP{linkend} để biết thêm chi tiết.",
-    "Unable to update background job mode" : "Không thể cập nhật chế độ công việc nền",
-    "Profile" : "Hồ sơ",
     "Unable to update profile default setting" : "Không thể cập nhật cài đặt mặc định của hồ sơ",
+    "Profile" : "Hồ sơ",
+    "Unable to update server side encryption config" : "Không thể cập nhật cấu hình mã hóa phía máy chủ",
     "Server-side encryption" : "Mã hoá phía máy chủ",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Mã hóa phía máy chủ giúp mã hóa các tệp được tải lên máy chủ này. Điều này đi kèm với những hạn chế như hình phạt về hiệu suất, vì vậy chỉ kích hoạt tính năng này nếu cần.",
     "Enable server-side encryption" : "Kích hoạt mã hoá phía máy chủ",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Không có mô-đun mã hóa nào được tải, vui lòng bật mô-đun mã hóa trong menu ứng dụng.",
+    "Select default encryption module:" : "Chọn mô-đun mã hóa mặc định:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Bạn cần di chuyển các khóa mã hóa của mình từ mã hóa cũ (ownCloud <= 8.0) sang mã hóa mới. Vui lòng bật \"Mô-đun mã hóa mặc định\" và chạy {command}",
+    "Enable encryption" : "Bật mã hóa",
     "Please read carefully before activating server-side encryption:" : "Vui lòng đọc kỹ trước khi kích hoạt mã hóa phía máy chủ:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Sau khi bật mã hóa, tất cả các tệp được tải lên máy chủ từ thời điểm đó trở đi sẽ được mã hóa ở phần còn lại trên máy chủ. Sau này, bạn chỉ có thể tắt tính năng mã hóa nếu mô-đun mã hóa đang hoạt động hỗ trợ chức năng đó và đáp ứng tất cả các điều kiện trước (ví dụ: đặt khóa khôi phục).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Mã hoá đơn phương không bảo đảm bảo mật hệ thống. Vui lòng xem tài liệu để biết thêm thông tin về cách hoạt động của mã hoá ứng dụng và những trường hợp hỗ trợ.",
     "Be aware that encryption always increases the file size." : "Xin lưu ý rằng mã hóa luôn làm tăng kích thước tệp.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Việc tạo bản sao lưu thường xuyên cho dữ liệu của bạn luôn là điều tốt, trong trường hợp mã hóa, hãy đảm bảo sao lưu các khóa mã hóa cùng với dữ liệu của bạn.",
     "This is the final warning: Do you really want to enable encryption?" : "Cảnh báo lần cuối: Bạn có thực sự muốn kích hoạt tính năng mã hoá?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Không có mô-đun mã hóa nào được tải, vui lòng bật mô-đun mã hóa trong menu ứng dụng.",
-    "Select default encryption module:" : "Chọn mô-đun mã hóa mặc định:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Bạn cần di chuyển các khóa mã hóa của mình từ mã hóa cũ (ownCloud <= 8.0) sang mã hóa mới. Vui lòng bật \"Mô-đun mã hóa mặc định\" và chạy {command}",
-    "Unable to update server side encryption config" : "Không thể cập nhật cấu hình mã hóa phía máy chủ",
     "Please confirm the group removal" : "Vui lòng xác nhận việc xóa nhóm",
-    "Cancel" : "Hủy",
-    "Confirm" : "Xác nhận",
     "Submit" : "Gửi đi",
     "Rename group" : "Đổi tên nhóm",
-    "Remove group" : "Xóa nhóm",
-    "Failed to remove group \"{group}\"" : "Không xóa được nhóm \"{group}\"",
     "Current password" : "Mật khẩu cũ",
     "New password" : "Mật khẩu mới",
-    "Change password" : "Đổi mật khẩu",
+    "Choose your profile picture" : "Chọn ảnh hồ sơ của bạn",
+    "Please select a valid png or jpg file" : "Vui lòng chọn tệp png hoặc jpg hợp lệ",
+    "Error setting profile picture" : "Lỗi cài đặt ảnh hồ sơ",
+    "Error cropping profile picture" : "Lỗi cắt ảnh hồ sơ",
+    "Error saving profile picture" : "Lỗi lưu ảnh hồ sơ",
+    "Error removing profile picture" : "Lỗi xóa ảnh hồ sơ",
     "Your profile picture" : "Hình ảnh cá nhân của bạn",
     "Upload profile picture" : "Tải ảnh hồ sơ lên",
     "Choose profile picture from Files" : "Chọn ảnh hồ sơ từ Tệp",
@@ -278,15 +285,8 @@ OC.L10N.register(
     "Picture provided by original account" : "Hình ảnh do tài khoản gốc cung cấp",
     "Set as profile picture" : "Thiết lập như là hình ảnh hồ sơ cá nhân",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Xin lưu ý rằng có thể mất tới 24 giờ để ảnh hồ sơ của bạn được cập nhật ở mọi nơi.",
-    "Choose your profile picture" : "Chọn ảnh hồ sơ của bạn",
-    "Please select a valid png or jpg file" : "Vui lòng chọn tệp png hoặc jpg hợp lệ",
-    "Error setting profile picture" : "Lỗi cài đặt ảnh hồ sơ",
-    "Error cropping profile picture" : "Lỗi cắt ảnh hồ sơ",
-    "Error saving profile picture" : "Lỗi lưu ảnh hồ sơ",
-    "Error removing profile picture" : "Lỗi xóa ảnh hồ sơ",
     "You are a member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
     "Your full name" : "Tên đầy đủ của bạn",
-    "Primary email for password reset and notifications" : "Email chính để đặt lại mật khẩu và thông báo",
     "Email options" : "Tùy chọn email",
     "Remove primary email" : "Xóa email chính",
     "Delete email" : "Xóa email",
@@ -299,13 +299,14 @@ OC.L10N.register(
     "Unable to add additional email address" : "Không thể thêm địa chỉ email bổ sung",
     "Unable to update additional email address" : "Không thể cập nhật địa chỉ email bổ sung",
     "Unable to delete additional email address" : "Không thể xóa địa chỉ email bổ sung",
+    "Primary email for password reset and notifications" : "Email chính để đặt lại mật khẩu và thông báo",
     "No email address set" : "Chưa thiết lập địa chỉ email",
     "Your headline" : "Tiêu đề của bạn",
-    "Help translate" : "Hỗ trợ dịch thuật",
     "Unable to update language" : "Không thể cập nhật ngôn ngữ",
+    "Help translate" : "Hỗ trợ dịch thuật",
     "No language set" : "Không có ngôn ngữ",
-    "Week starts on {firstDayOfWeek}" : "Tuần bắt đầu vào {firstDayOfWeek}",
     "Unable to update locale" : "Không thể cập nhật ngôn ngữ",
+    "Week starts on {firstDayOfWeek}" : "Tuần bắt đầu vào {firstDayOfWeek}",
     "No locale set" : "Không có ngôn ngữ nào được đặt",
     "Your city" : "Thành phố",
     "Your organisation" : "Tổ chức",
@@ -315,23 +316,24 @@ OC.L10N.register(
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Cài đặt hạn chế hơn về khả năng hiển thị hoặc phạm vi được tôn trọng trên Hồ sơ của bạn. Ví dụ: nếu mức độ hiển thị được đặt thành \"Hiển thị cho mọi người\" và phạm vi được đặt thành \"Riêng tư\" thì \"Riêng tư\" sẽ được tôn trọng.",
     "Unable to update visibility of {displayId}" : "Không thể cập nhật mức độ hiển thị của {displayId}",
     "Your role" : "Vai trò của bạn",
+    "Timezone" : "Múi giờ",
     "Your website" : "Trang web của bạn",
-    "No {property} set" : "Không có  {property} nào được đặt",
     "Unable to update {property}" : "Không thể cập nhật {property}",
+    "No {property} set" : "Không có  {property} nào được đặt",
     "Change scope level of {property}, current scope is {scope}" : "Thay đổi cấp độ phạm vi của {property}, phạm vi hiện tại là {scope}",
     "Unable to update federation scope of the primary {property}" : "Không thể cập nhật phạm vi liên kết của {property} chính",
     "Unable to update federation scope of additional {property}" : "Không thể cập nhật phạm vi liên kết của {property} bổ sung",
     "Add additional email" : "Thêm email bổ sung",
     "Add" : "Thêm",
-    "Create" : "Tạo mới",
-    "Change" : "Chỉnh sửa",
+    "Create" : "Tạo",
+    "Change" : "Thay đổi",
     "Delete" : "Xóa",
     "Reshare" : "Chia sẻ lại",
     "Default language" : "Ngôn ngữ mặc định",
     "Common languages" : "Ngôn ngữ thông dụng",
     "Other languages" : "Những ngôn ngữ khác",
     "Password change is disabled because the master key is disabled" : "Thay đổi mật khẩu bị vô hiệu hóa vì khóa chính bị vô hiệu hóa",
-    "Display name" : "Tên hiển thị",
+    "Manager" : "Giám đốc",
     "Either password or email is required" : "Cần có mật khẩu hoặc email",
     "Password (required)" : "Mật khẩu (được yêu câu)",
     "Email (required)" : "Email (bắt buộc)",
@@ -339,24 +341,18 @@ OC.L10N.register(
     "Quota" : "Hạn ngạch",
     "Language" : "Ngôn ngữ",
     "Set default language" : "Đặt ngôn ngữ mặc định",
-    "Manager" : "Giám đốc",
-    "Total rows summary" : "Tóm tắt tổng số hàng",
+    "Total rows summary" : "Tổng số hàng",
     "Scroll to load more rows" : "Cuộn để tải thêm hàng",
+    "Password or insufficient permissions message" : "Mật khẩu hoặc thông báo không đủ quyền",
     "Avatar" : "Hình đại diện",
     "Account name" : "Tên tài khoản",
     "Group admin for" : "Quản trị viên nhóm",
     "Storage location" : "Khu vực lưu trữ",
     "Last login" : "Lần đăng nhập cuối",
     "Account actions" : "Hành động với tài khoản",
-    "Password or insufficient permissions message" : "Mật khẩu hoặc thông báo không đủ quyền",
-    "Change display name" : "Thay đổi tên hiển thị",
-    "Set new password" : "Đặt mật khẩu mới",
-    "Set new email address" : "Đặt địa chỉ email mới",
-    "Set the language" : "Đặt ngôn ngữ",
     "{size} used" : "{size} đã sử dụng",
     "Delete account" : "Xóa tài khoản",
     "Resend welcome email" : "Gửi lại email chào mừng",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
     "Remote wipe of devices" : "Xóa thiết bị từ xa",
     "Wipe {userid}'s devices" : "Xóa thiết bị của {userid}",
     "Wiped {userid}'s devices" : "Đã xóa thiết bị của {userid}",
@@ -367,7 +363,11 @@ OC.L10N.register(
     "Password was successfully changed" : "Mật khẩu đã được thay đổi thành công",
     "Email was successfully changed" : "Email đã được thay đổi thành công",
     "Welcome mail sent!" : "Thư chào mừng đã được gửi!",
-    "Done" : "Hoàn thành",
+    "Change display name" : "Thay đổi tên hiển thị",
+    "Set new password" : "Đặt mật khẩu mới",
+    "Set new email address" : "Đặt địa chỉ email mới",
+    "Set the language" : "Đặt ngôn ngữ",
+    "Done" : "Hoàn tất",
     "Edit" : "Chỉnh sửa",
     "Visibility" : "Hiển thị",
     "Show language" : "Hiển thị ngôn ngữ",
@@ -377,24 +377,26 @@ OC.L10N.register(
     "Defaults" : "Mặc định",
     "Default quota" : "Hạn ngạch mặc định",
     "Select default quota" : "Chọn hạn ngạch mặc định",
+    "Server error while trying to complete WebAuthn device registration" : "Lỗi máy chủ khi cố gắng hoàn tất đăng ký thiết bị WebAuthn",
     "Passwordless authentication requires a secure connection." : "Xác thực không cần mật khẩu yêu cầu kết nối an toàn.",
     "Add WebAuthn device" : "Thêm thiết bị WebAuthn",
     "Please authorize your WebAuthn device." : "Vui lòng ủy quyền cho thiết bị WebAuthn của bạn.",
     "Adding your device …" : "Đang thêm thiết bị của bạn…",
-    "Server error while trying to complete WebAuthn device registration" : "Lỗi máy chủ khi cố gắng hoàn tất đăng ký thiết bị WebAuthn",
     "Unnamed device" : "Thiết bị chưa được đặt tên",
     "Passwordless Authentication" : "Xác thực không cần mật khẩu",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Thiết lập tài khoản của bạn để xác thực không cần mật khẩu theo tiêu chuẩn FIDO2.",
     "No devices configured." : "Không có thiết bị nào được định cấu hình.",
     "The following devices are configured for your account:" : "Các thiết bị sau được định cấu hình cho tài khoản của bạn:",
     "Your browser does not support WebAuthn." : "Trình duyệt của bạn không hỗ trợ WebAuthn.",
+    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
+    "Try again" : "Thử lại",
+    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
+    "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
+    "There are some warnings regarding your setup." : "Có một số cảnh báo liên quan đến thiết lập của bạn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Với tư cách là quản trị viên, bạn có thể tinh chỉnh hành vi chia sẻ. Vui lòng xem tài liệu để biết thêm thông tin.",
     "You need to enable the File sharing App." : "Bạn cần kích hoạt Ứng dụng chia sẻ tệp.",
+    "Apply" : "Áp dụng",
     "Admins" : "Quản trị viên",
-    "Create group" : "Tạo nhóm",
-    "Group name" : "Tên nhóm",
-    "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
-    "Failed to create group" : "Không tạo được nhóm",
     "Sending…" : "Đang gửi...",
     "Email sent" : "Email đã được gửi",
     "Location" : "Vị trí",
@@ -423,7 +425,6 @@ OC.L10N.register(
     "Disable" : "Tắt",
     "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
     "The app will be downloaded from the App Store" : "Ứng dụng sẽ được tải xuống từ App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
     "Unknown" : "Không xác định",
     "Never" : "Không bao giờ",
     "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
@@ -456,88 +457,16 @@ OC.L10N.register(
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Test and verify email settings" : "Kiểm tra và xác minh cài đặt email",
-    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
-    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
-    "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
-    "There are some warnings regarding your setup." : "Có một số cảnh báo liên quan đến thiết lập của bạn.",
-    "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật.",
     "Use a second factor besides your password to increase security for your account." : "Sử dụng yếu tố thứ hai ngoài mật khẩu để tăng tính bảo mật cho tài khoản của bạn.",
-    "No user supplied" : "Không có người dùng cung cấp",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vui lòng cung cấp mật khẩu khôi phục quản trị viên; nếu không, tất cả dữ liệu người dùng sẽ bị mất.",
-    "Backend does not support password change, but the user's encryption key was updated." : "Hệ thống không hỗ trợ đổi mật khẩu, nhưng khoá mã hoá của người dùng đã được cập nhật.",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Bạn cần đặt email người dùng của mình trước khi có thể gửi email kiểm tra. Đi tới %s để biết điều đó.",
-    "Invalid user" : "Người dùng không hợp lệ",
-    "Your username is: %s" : "Tên người dùng của bạn là : %s",
-    "Logged in user must be a subadmin" : "Người dùng đã đăng nhập phải là một subadmin",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Một công việc nền đang chờ xử lý để kiểm tra chứng chỉ SSL đã nhập của người dùng. Vui lòng kiểm tra lại sau.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Có một số chứng chỉ SSL do người dùng nhập hiện không còn được sử dụng với Nextcloud 21. Chúng có thể được nhập trên dòng lệnh thông qua lệnh \"occ security:certificates:import\". Đường dẫn của chúng bên trong thư mục dữ liệu được hiển thị bên dưới.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Cơ sở dữ liệu thiếu một số mục. Do thực tế là việc thêm mục trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-indices\", các mục bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các mục được thêm vào, các truy vấn vào các bảng đó thường nhanh hơn nhiều.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Bạn hiện đang chạy PHP %s. PHP 8.0 hiện không được dùng nữa trong Nextcloud 27. Nextcloud 28 có thể yêu cầu ít nhất PHP 8.1. Vui lòng nâng cấp lên một trong các phiên bản PHP được hỗ trợ chính thức do Nhóm PHP cung cấp càng sớm càng tốt.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Phiên bản MariaDB \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu MariaDB 10.2 trở lên.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Phiên bản MySQL \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu MySQL 8.0 hoặc MariaDB 10.2 trở lên.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Phiên bản PostgreSQL \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu PostgreSQL 9.6 trở lên.",
-    "Speech-To-Text" : "Chuyển giọng nói thành văn bản",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Chuyển giọng nói thành văn bản có thể được triển khai bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng Chuyển giọng nói thành văn bản",
-    "None of your currently installed apps provide Text processing functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng xử lý văn bản",
-    "Exclude groups from sharing" : "Loại trừ các nhóm khỏi việc chia sẻ",
-    "These groups will still be able to receive shares, but not to initiate them." : "Các nhóm này vẫn có thể nhận được lượt chia sẻ nhưng không thể bắt đầu chia sẻ.",
     "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Cho phép tự động hoàn thành tên người dùng trong hộp thoại chia sẻ và cho phép truy cập vào sổ địa chỉ hệ thống",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Xác thực hai yếu tố có thể được thực thi cho tất cả người dùng và các nhóm cụ thể. Nếu họ không cấu hình nhà cung cấp hai yếu tố, họ sẽ không thể đăng nhập vào hệ thống.",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Khi các nhóm được chọn / loại trừ, họ sử dụng logic sau để xác định xem người dùng có thực thi 2FA hay không: Nếu không có nhóm nào được chọn, 2FA được bật cho mọi người trừ các thành viên của các nhóm bị loại trừ. Nếu các nhóm được chọn, 2FA được bật cho tất cả các thành viên trong số này. Nếu người dùng ở cả hai nhóm được chọn và bị loại trừ, quyền được chọn sẽ được ưu tiên và 2FA được thi hành.",
-    "{license}-licensed" : "{license}-được cấp phép",
-    "Username" : "Tên đăng nhập",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Thực hiện một tác vụ với mỗi trang được tải. Trường hợp sử dụng: Phiên bản người dùng duy nhất.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php được đăng ký tại dịch vụ webcron để gọi cron.php cứ 5 phút một lần qua HTTP. Ca sử dụng: Phiên bản rất nhỏ (1–5 người dùng tùy theo mức độ sử dụng).",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php cần được thực thi bởi người dùng hệ thống \"{user}\".",
-    "Enable or disable profile by default for new users." : "Bật hoặc tắt hồ sơ theo mặc định cho người dùng mới.",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Bạn sắp xóa nhóm \"{group}\". Người dùng sẽ KHÔNG bị xóa.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
     "Your biography" : "Tiểu sử của bạn",
     "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
-    "Additional emails" : "Email bổ sung",
-    "Enable Profile" : "Bật hồ sơ",
-    "No users" : "Không có người dùng",
-    "Loading users …" : "Đang tải người dùng…",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Danh sách người dùng. Danh sách này không được hiển thị đầy đủ vì lý do hiệu suất. Người dùng sẽ được hiển thị khi bạn điều hướng qua danh sách.",
-    "New user" : "Người dùng mới",
-    "Groups (required)" : "Nhóm (bắt buộc)",
-    "Set user groups" : "Đặt nhóm người dùng",
-    "Administered groups" : "Nhóm được quản lý",
-    "Set user as admin for …" : "Đặt người dùng làm quản trị viên cho…",
-    "Set user quota" : "Đặt hạn ngạch người dùng",
-    "Add new user" : "Thêm người dùng mới",
-    "Set user manager" : "Đặt trình quản lý người dùng",
-    "Username will be autogenerated" : "Tên người dùng sẽ được tạo tự động",
-    "Username (required)" : "Tên người dùng (bắt buộc)",
-    "User backend" : "Trang cài đặt người dùng",
-    "User actions" : "Hành động của người dùng",
-    "Loading user …" : "Đang tải người dùng…",
-    "You do not have permissions to see the details of this user" : "Bạn không có quyền xem chi tiết của người dùng này",
-    "Add user to group" : "Thêm người dùng vào nhóm",
-    "Set user as admin for" : "Đặt người dùng làm quản trị viên cho",
-    "Select user quota" : "Chọn hạn ngạch người dùng",
-    "Delete user" : "Xóa người dùng",
-    "Wipe all devices" : "Xóa sạch tất cả các thiết bị",
-    "Disable user" : "Vô hiệu hóa người dùng",
-    "Enable user" : "Kích hoạt người dùng",
-    "Failed to update user manager" : "Không cập nhật được trình quản lý người dùng",
-    "Toggle user actions menu" : "Chuyển đổi menu hành động của người dùng",
-    "User management settings" : "Cài đặt quản lý người dùng",
-    "Show user backend" : "Hiển thị cài đặt người dùng",
-    "Send welcome email to new users" : "Gửi email chào mừng tới người dùng mới",
-    "Name your device" : "Đặt tên cho thiết bị của bạn",
-    "Server error while trying to add WebAuthn device" : "Lỗi máy chủ khi cố gắng thêm thiết bị WebAuthn",
-    "by {author}\n{license}" : "bởi {author}\n{license}",
-    "Active users" : "Người dùng hoạt động",
-    "Disabled users" : "Người dùng đã bị vô hiệu hóa",
-    "Creating group …" : "Đang tạo nhóm…",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Không khả dụng vì liên kết đã bị vô hiệu hóa đối với tài khoản của bạn, hãy liên hệ với quản trị viên hệ thống nếu bạn có bất kỳ câu hỏi nào",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Không có sẵn vì không được phép xuất bản dữ liệu cụ thể của người dùng lên máy chủ tra cứu, hãy liên hệ với quản trị viên hệ thống của bạn nếu bạn có bất kỳ câu hỏi nào",
-    "Show to logged in users only" : "Chỉ hiển thị cho người dùng đã đăng nhập",
-    "Nextcloud help resources" : "Tài nguyên trợ giúp của Nextcloud",
-    "SMTP Username" : "Tên người dùng SMTP"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
+    "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật."
 },
 "nplurals=1; plural=0;");
