@@ -44,10 +44,11 @@ OC.L10N.register(
     "The provided check value is too long" : "Предоставената стойност за проверка е твърде дълга",
     "Check #%s does not exist" : "Проверка #%s не съществува",
     "Check %s is invalid or does not exist" : "Проверка %s не е валидна или несъществува",
-    "Flow" : "Поток",
+    "Flow" : "Автоматизация",
     "Nextcloud workflow engine" : "Система на работния поток на Nextcloud",
     "Select a filter" : "Избор на филтър",
     "Select a comparator" : "Избор на инструмент за сравняване",
+    "Remove filter" : "Премахни филтър",
     "Folder" : "Папка",
     "Images" : "Изображения",
     "Office documents" : "Офис документи",
@@ -69,7 +70,7 @@ OC.L10N.register(
     "Select groups" : "Избери Групи",
     "Groups" : "Групи",
     "At least one event must be selected" : "Трябва да бъде избрано поне едно събитие",
-    "Add new flow" : "Добавяне на нов поток",
+    "Add new flow" : "Добавяне на нова автоматизация",
     "The configuration is invalid" : "Конфигурацията е невалидна",
     "Active" : "Активен",
     "Save" : "Запази",
@@ -77,14 +78,17 @@ OC.L10N.register(
     "and" : "и",
     "Cancel" : "Отказ",
     "Delete" : "Изтриване",
-    "Available flows" : "Налични потоци",
+    "Available flows" : "Налични автоматизации",
     "For details on how to write your own flow, check out the development documentation." : "За подробности как да напишете свой собствен поток, вижте документацията за разработка.",
-    "More flows" : "Още потоци",
+    "No flows installed" : "Няма инсталирани автоматизации",
+    "Ask your administrator to install new flows." : "Помолете системния администратор да инсталира нови автоматизации",
+    "More flows" : "Още поточни автоматизации",
     "Browse the App Store" : "Преглед на магазина за приложения /App Store/",
     "Show less" : "Покажи по-малко",
     "Show more" : "Покажи повече",
-    "Configured flows" : "Конфигурирани потоци",
-    "Your flows" : "Вашите потоци ",
+    "Configured flows" : "Конфигурирани поточни автоматизации",
+    "Your flows" : "Вашите автоматизации",
+    "No flows configured" : "Няма конфигурирани автоматизации",
     "matches" : "съвпадения",
     "does not match" : "не съвпада",
     "is" : "е",
