@@ -51,6 +51,11 @@ OC.L10N.register(
     "No translation provider available" : "لا توجد خدمة للترجمة",
     "Could not detect language" : "لم يُمكن اكتشاف اللغة",
     "Unable to translate" : "لم يُمكن الترجمة",
+    "[%d / %d]: %s" : "[%d/%d]: %s",
+    "Repair step:" : "خطوة صيانة:",
+    "Repair info:" : "معلومات صيانة:",
+    "Repair warning:" : "تحذير صيانة:",
+    "Repair error:" : "خطأ صيانة:",
     "Nextcloud Server" : "خادم نكست كلاود",
     "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "أدخِل مفتاح الاشتراك الخاص بك في تطبيق الدعم لزيادة حد الأقصى من الحسابات. يمنحك هذا أيضًا جميع المزايا الإضافية التي يقدمها Nextcloud Enterprise ويوصى به بشدة للشركات و المؤسسات.",
     "Learn more ↗" : "تعلم المزيد ↗",
     "Preparing update" : "جارٍ تهيئة التحديث",
-    "[%d / %d]: %s" : "[%d/%d]: %s",
-    "Repair step:" : "خطوة صيانة:",
-    "Repair info:" : "معلومات صيانة:",
-    "Repair warning:" : "تحذير صيانة:",
-    "Repair error:" : "خطأ صيانة:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "يرجى الترقية من خلال سطر الأوامر command line updater حيث أن الترقية من المستعرض معطلة في ملف config.php.",
     "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
     "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
@@ -79,8 +79,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (غير متوافق)",
     "The following apps have been disabled: %s" : "التطبيقات التاليه غير مفعله: %s",
     "Already up to date" : "محدّثة مسبقاً",
-    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
+    "Unknown" : "غير معروف",
+    "PNG image" : "صورة PNG",
     "unknown text" : "النص غير معروف",
     "Hello world!" : "مرحبا بالعالم!",
     "sunny" : "مشمس",
@@ -109,7 +109,6 @@ OC.L10N.register(
     "Federated user" : "مستخدم السحابة الموحدة",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "إنشاء مشاركة",
-    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة",
     "Please copy the link manually:" : "يرجى نسخ الرابط يدوياً:",
     "Custom date range" : "نطاق زمني مخصص",
     "Pick start date" : "إختر تاريخ البدء",
@@ -300,9 +299,9 @@ OC.L10N.register(
     "Admin" : "المدير",
     "Help" : "المساعدة",
     "Access forbidden" : "الوصول محظور",
+    "Back to %s" : "العودة إلى %s",
     "Page not found" : "الصفحة غير موجودة",
     "The page could not be found on the server or you may not be allowed to view it." : "لم يُمكن إيجاد الصفحة على الخادم أو ربما غير مسموح لك بالوصول إليها.",
-    "Back to %s" : "العودة إلى %s",
     "Too many requests" : "الطلبات أقصى من الحد المسموح",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
     "Error" : "خطأ",
@@ -378,16 +377,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
     "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
-    "Currently open" : "مفتوح حاليّاً ",
-    "Login with username or email" : "الدخول باسم المستخدم أو البريد الإلكتروني",
-    "Login with username" : "الدخول باسم المستخدم",
+    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة ومكالمات الفيديو ومشاركة الشاشة والإجتماعات عبر الإنترنت ومؤتمرات الويب - في متصفحك ومع تطبيق للهاتف المحمول.",
     "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
     "{user} has not added any info yet" : "لم يقم المستخدم {user} بإضافة أي معلومات بعد",
     "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
     "Edit Profile" : "تعديل الملف الشخصي",
     "The headline and about sections will show up here" : "سيظهر هنا العنوان والأقسام الخاصة بالملف الشخصي",
-    "Error loading message template: {error}" : "حصل خطأ في القالب: {error}",
     "Very weak password" : "كلمة السر ضعيفة جدا",
     "Weak password" : "كلمة السر ضعيفة",
     "So-so password" : "كلمة سر غير فعالة",
@@ -404,6 +401,7 @@ OC.L10N.register(
     "Toggle password visibility" : "تبديل قراءة كلمة المرور",
     "Configure the database" : "إعداد قاعدة البيانات",
     "Only %s is available." : "لم يتبقى إلّا %s.",
-    "Database account" : "حساب قاعدة البيانات"
+    "Database account" : "حساب قاعدة البيانات",
+    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
