@@ -27,8 +27,10 @@ OC.L10N.register(
     "Could not complete login" : "Не може да завърши влизането",
     "State token missing" : "Липсва токен/маркер/ на състоянието",
     "Your login token is invalid or has expired" : "Вашият маркер за вход е невалиден или е изтекъл",
+    "Please use original client" : "Моля, използвайте оригиналния клиент.",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Тази общностна версия на Nextcloud не се поддържа и push известия са ограничени.",
     "Login" : "Вписване",
+    "Unsupported email length (>255)" : "Дължината на е-мейлът не се поддържа (>255 символа)",
     "Password reset is disabled" : "Възстановяването на пароли е забранено",
     "Could not reset password because the token is expired" : "Възстановяването на паролата е неуспешно, защото токенът е с изтекла валидност",
     "Could not reset password because the token is invalid" : "Възстановяването на паролата е неуспешно, защото токенът е невалиден",
@@ -38,21 +40,28 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следния бутон, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следната връзка, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Reset your password" : "Възстановяване на вашата парола",
+    "The given provider is not available" : "Доставчикът не е наличен",
+    "Task not found" : "Задачата не е открита",
     "Internal error" : "Вътрешна грешка",
     "Not found" : "Не е намерен",
+    "Node is locked" : "Точката е заключена (Node is locked)",
+    "Bad request" : "Лоша заявка",
+    "Requested task type does not exist" : "Заявената задача не съществува",
+    "Image not found" : "Изображението не е открито",
     "No translation provider available" : "Няма наличен доставчик на преводи",
     "Could not detect language" : "Не можа да се установи езика",
     "Unable to translate" : "Не може да се преведе",
-    "Nextcloud Server" : "Nextcloud сървър",
-    "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
-    "Learn more ↗" : "Научете повече ↗",
-    "Preparing update" : "Подготовка за актуализиране",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Стъпка на поправка:",
     "Repair info:" : "Информация за поправка:",
     "Repair warning:" : "Предупреждение при поправка:",
     "Repair error:" : "Грешка при поправка:",
+    "Nextcloud Server" : "Nextcloud сървър",
+    "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Въведете своя абонаментен ключ в приложението за поддръжка, за да увеличите лимита на акаунта.  Това също ви предоставя всички допълнителни предимства, които Nextcloud Enterprise предлага и е силно препоръчително за работа в компании.",
+    "Learn more ↗" : "Научете повече ↗",
+    "Preparing update" : "Подготовка за актуализиране",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Моля, използвайте програмата за актуализиране от командния ред, тъй като актуализирането чрез браузъра е забранено в config.php.",
     "Turned on maintenance mode" : "Режимът за поддръжка е включен",
     "Turned off maintenance mode" : "Режимът за поддръжка е изключен",
@@ -69,8 +78,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (несъвместим)",
     "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
     "Already up to date" : "Актуално",
-    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
+    "Unknown" : "Неизвестен",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здравей Свят!",
     "sunny" : "слънчево",
@@ -92,42 +100,61 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} известие","{count} известия"],
     "No" : "Не",
     "Yes" : "Да",
-    "Create share" : "Създаване на споделяне",
+    "Invalid remote URL." : "невалиден отдалечен URL(адрес)",
     "Failed to add the public link to your Nextcloud" : "Неуспешно добавяне на публичната връзка към вашия Nextcloud",
+    "Create share" : "Създаване на споделяне",
+    "Please copy the link manually:" : "Моля копирайте адреса ръчно:",
+    "Search in date range" : "Търси във времеви период",
+    "Search in current app" : "Търси в настоящето приложение",
+    "Clear search" : "Изчисти търсенето",
+    "Search everywhere" : "Търси навсякъде",
+    "Searching …" : "Търсене ...",
+    "Start typing to search" : "Започнете да пишете, за търсене",
+    "Today" : "Днес",
+    "Last 7 days" : "Последните 7 дни",
+    "Last 30 days" : "Последните 30 дни",
+    "This year" : "Тази година",
+    "Last year" : "Миналата година",
+    "Unified search" : "Глобално търсене",
+    "Search apps, files, tags, messages" : "Търси приложения, файлове, тагове, съобщения",
     "Places" : "Места",
     "Date" : "Дата",
-    "Today" : "Днес",
-    "Last year" : "Миналата година",
+    "Search people" : "Търси хора",
     "People" : "Хора",
     "Results" : "Резултати",
     "Load more results" : "Зареждане на още резултати",
-    "Searching …" : "Търсене ...",
-    "Start typing to search" : "Започнете да пишете, за търсене",
+    "Search in" : "Търси в",
     "Log in" : "Вписване",
     "Logging in …" : "Вписване ...",
+    "Log in to {productName}" : "Вписване в {productName}",
+    "This account is disabled" : "Профилът е неактивен",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
+    "Account name or email" : "Име на профил или имейл",
+    "Account name" : "Име на профил",
     "Server side authentication failed!" : "Неуспешно удостоверяването от страна на сървъра!",
     "Please contact your administrator." : "Моля, свържете се с администратора.",
     "An internal error occurred." : "Възникна вътрешно сървърна грешка.",
     "Please try again or contact your administrator." : "Опитайте отново или се свържете с администраотра.",
     "Password" : "Парола",
-    "Log in to {productName}" : "Вписване в {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
-    "Account name or email" : "Име на профил или имейл",
-    "Account name" : "Име на профил",
     "Log in with a device" : "Вписване с устройство",
     "Your account is not setup for passwordless login." : "Вашият профил не е настроен за влизане без парола.",
-    "Browser not supported" : "Браузърът не се поддържа",
-    "Passwordless authentication is not supported in your browser." : "Удостоверяването без парола не се поддържа във вашия браузър.",
     "Your connection is not secure" : "Връзката ви не е сигурна",
     "Passwordless authentication is only available over a secure connection." : "Удостоверяването без парола е достъпно само чрез защитена връзка.",
+    "Browser not supported" : "Браузърът не се поддържа",
+    "Passwordless authentication is not supported in your browser." : "Удостоверяването без парола не се поддържа във вашия браузър.",
     "Reset password" : "Възстановяване на паролата",
+    "Back to login" : "Обратно към вписване",
     "Couldn't send reset email. Please contact your administrator." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, свържете се с вашия администратор.",
     "Password cannot be changed. Please contact your administrator." : "Паролата не може да бъде променена. Моля, свържете се с вашия администратор.",
-    "Back to login" : "Обратно към вписване",
     "New password" : "Нова парола",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашите файлове са криптирани. След като паролата ви бъде нулирана, няма да можете да си върнете данните. Ако не сте сигурни какво да правите, моля, свържете се с вашия администратор, преди да продължите. Наистина ли искате да продължите?",
     "I know what I'm doing" : "Знам какво правя",
     "Resetting password" : "Възстановяване на паролата",
+    "Schedule work & meetings, synced with all your devices." : "Планирайте работа и срещи, синхронизирано с всичките ви устройства.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Бъдете с колегите и приятелите си на едно място, без да изтича тяхната лична информация.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Опростено приложение за електронна поща, добре интегрирано с файлове, контакти и календар.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
+    "Distraction free note taking app." : "Приложение за водене на бележки без разсейване.",
     "Recommended apps" : "Препоръчани приложения",
     "Loading apps …" : "Зареждане на приложения ...",
     "Could not fetch list of apps from the App Store." : "Списъкът с приложения не можа да се извлече от App Store.",
@@ -137,43 +164,52 @@ OC.L10N.register(
     "Skip" : "Пропускане",
     "Installing apps …" : "Инсталиране на приложения ...",
     "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
-    "Schedule work & meetings, synced with all your devices." : "Планирайте работа и срещи, синхронизирано с всичките ви устройства.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Бъдете с колегите и приятелите си на едно място, без да изтича тяхната лична информация.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Опростено приложение за електронна поща, добре интегрирано с файлове, контакти и календар.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
-    "Distraction free note taking app." : "Приложение за водене на бележки без разсейване.",
     "Settings menu" : "Настройки",
-    "Search contacts" : "Търсене на/в/ контакти",
-    "Reset search" : "Рестартирай търсенето",
+    "Loading your contacts …" : "Зареждане на контактите ...",
+    "Looking for {term} …" : "Търси се {term} …",
+    "Search contacts" : "Търсене в контакти",
+    "Reset search" : "Ново търсене",
     "Search contacts …" : "Търсене в контактите ...",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
     "No contacts found" : "Няма намерени контакти",
     "Show all contacts" : "Показване на всички контакти",
     "Install the Contacts app" : "Инсталиране на приложението за Контакти ",
-    "Loading your contacts …" : "Зареждане на контактите ...",
-    "Looking for {term} …" : "Търси се {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Търсенето започва, след като започнете да пишете, а до резултатите можете да стигнете с клавишите със стрелки.",
-    "Search for {name} only" : "Търсене само за {name}",
-    "Loading more results …" : "Зарежда още резултати…",
     "Search" : "Търсене",
     "No results for {query}" : "Няма резултати за {query}",
     "Press Enter to start searching" : "Натиснете Enter, за стартиране на търсенето",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Моля, въведете {minSearchLength} знака или повече, за да търсите","Моля, въведете {minSearchLength} знака или повече, за да търсите"],
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Търсенето започва, след като започнете да пишете, а до резултатите можете да стигнете с клавишите със стрелки.",
+    "Search for {name} only" : "Търсене само за {name}",
+    "Loading more results …" : "Зарежда още резултати…",
     "Forgot password?" : "Забравена парола?",
     "Back" : "Назад",
     "Login form is disabled." : "Формулярът за вход е деактивиран",
-    "Edit Profile" : "Редактиране на профил",
-    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
-    "You have not added any info yet" : "Все още не сте добавили никаква информация",
-    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
-    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
     "More actions" : "Повече действия",
+    "Security warning" : "Предупреждение за сигурност",
+    "Storage & database" : "Хранилища и бази данни",
+    "Data folder" : "Директория за данни",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
+    "For more details check out the documentation." : "За повече информация проверете документацията.",
+    "Performance warning" : "Предупреждение за производителността",
+    "You chose SQLite as database." : "Избрахте база данни SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite трябва да се използва само за минимални екземпляри и екземпляри за разработка. За производство препоръчваме различен сървър на базата данни.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако използвате клиенти за синхронизиране на файлове, използването на SQLite не се препоръчва.",
+    "Database user" : "Потребител за базата данни",
+    "Database password" : "Парола за базата данни",
+    "Database name" : "Име на базата данни",
+    "Database tablespace" : "Tablespace на базата данни",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
+    "Database host" : "Хост",
+    "Installing …" : "В процес на инсталиране…",
+    "Install" : "Инсталиране",
+    "Need help?" : "Нуждаете се от помощ?",
+    "See the documentation" : "Прегледайте документацията",
+    "{name} version {version} and above" : "{name} версия {version} и по-нови",
     "This browser is not supported" : "Този браузър не се поддържа",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
-    "{name} version {version} and above" : "{name} версия {version} и по-нови",
     "Search {types} …" : "Търсене на  {types}  ...",
     "Choose" : "Избор",
     "Copy" : "Копирай",
@@ -206,11 +242,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
     "New in" : "Ново в",
     "View changelog" : "Преглед на списъка с промени",
-    "Very weak password" : "Много проста парола",
-    "Weak password" : "Проста парола",
-    "So-so password" : "Не особено добра парола",
-    "Good password" : "Добра парола",
-    "Strong password" : "Сложна парола",
     "No action available" : "Няма налични действия",
     "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Close \"{dialogTitle}\" dialog" : "Затваряне на диалогов прозорец \"{dialogTitle}\"",
@@ -222,11 +253,10 @@ OC.L10N.register(
     "Collaborative tags" : "Съвместни етикети",
     "No tags found" : "Не са открити етикети",
     "Personal" : "Лични",
+    "Accounts" : "Профили",
     "Admin" : "Админ",
     "Help" : "Помощ",
     "Access forbidden" : "Достъпът е забранен",
-    "Profile not found" : "Профилът не е намерен",
-    "The profile does not exist." : "Профилът не съществува.",
     "Back to %s" : "Обратно към %s",
     "Page not found" : "Страницата не е намерена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страницата не може да бъде намерена на сървъра или може да не ви е позволено да я видите.",
@@ -246,31 +276,6 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Ред: %s",
     "Trace" : "Проследяване на грешките",
-    "Security warning" : "Предупреждение за сигурност",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
-    "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
-    "Show password" : "Покажи парола",
-    "Toggle password visibility" : "Превключване на видимостта на парола",
-    "Storage & database" : "Хранилища и бази данни",
-    "Data folder" : "Директория за данни",
-    "Configure the database" : "Конфигуриране на базата данни",
-    "Only %s is available." : "Само %s е наличен.",
-    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
-    "For more details check out the documentation." : "За повече информация проверете документацията.",
-    "Database password" : "Парола за базата данни",
-    "Database name" : "Име на базата данни",
-    "Database tablespace" : "Tablespace на базата данни",
-    "Database host" : "Хост",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
-    "Performance warning" : "Предупреждение за производителността",
-    "You chose SQLite as database." : "Избрахте база данни SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite трябва да се използва само за минимални екземпляри и екземпляри за разработка. За производство препоръчваме различен сървър на базата данни.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако използвате клиенти за синхронизиране на файлове, използването на SQLite не се препоръчва.",
-    "Install" : "Инсталиране",
-    "Installing …" : "В процес на инсталиране…",
-    "Need help?" : "Нуждаете се от помощ?",
-    "See the documentation" : "Прегледайте документацията",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Изглежда, че се опитвате да преинсталирате Nextcloud. Файлът CAN_INSTALL обаче липсва във вашата конфигурационна директория. Моля, създайте файла CAN_INSTALL във вашата конфигурационна папка, за да продължите.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL не можа да се премахне от конфигурационната папка. Моля, премахнете този файл ръчно.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Приложението изисква JavaScript. Моля, {linkstart}включете JavaScript{linkend} и презаредете страницата.",
@@ -326,33 +331,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
-    "The user limit of this instance is reached." : " Достигнат е потребителският лимит на този екземпляр.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Въведете абонаментния си ключ в приложението за поддръжка, за да увеличите лимита на потребителите. Това ви дава и всички допълнителни предимства, които Nextcloud Enterprise предлага, и е силно препоръчително за работа в компании.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашият уеб сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът не работи.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Вашият уеб сървър не е настроен правилно за разрешаване на \"{url}\". Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Вашият уеб сървър не е настроен правилно за разрешаване на \"{url}\". Това най-вероятно е свързано с конфигурация на уеб сървър, която не е актуализирана, за да доставя тази папка директно. Моля, сравнете конфигурацията си с изпратените правила за пренаписване в \".htaccess\" за Apache или предоставеното в документацията за Nginx, на неговата {linkstart}странница за документация ↗{linkend}. В Nginx това обикновено са редовете, започващи с „location ~“/местоположение/, които се нуждаят от актуализация. ",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Вашият уеб сървър не е правилно настроен да доставя .woff2 файлове. Това обикновено е проблем с конфигурацията на Nginx. За Nextcloud 15 се нуждае от корекция, за да доставя и .woff2 файлове. Сравнете вашата конфигурация на Nginx с препоръчаната конфигурация в нашата {linkstart}документация ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Вие имате достъп до вашия екземпляр през защитена връзка, но вашият екземпляр генерира несигурни URL адреси. Това най-вероятно означава, че сте зад обратен прокси и конфигурационните променливи за презаписване не са зададени правилно. Моля, прочетете {linkstart}страницата с документация за това ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроите по подходящ начин тази настройка.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Някои функции може да не работят правилно, тъй като се препоръчва да настроите по подходящ начин тази настройка.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не съдържа „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да коригирате по подходящ начин тази настройка.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавката \"{header}\" не е зададена на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Това може да доведе до изтичане на референтна информация. Вижте {linkstart}препоръката на W3C ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP заглавката \"Strict-Transport-Security\" не е настроена на поне \"{seconds}\" секунди. За подобрена сигурност се препоръчва да активирате HSTS, както е описано в {linkstart}съветите за сигурност ↗{linkend}.",
-    "Currently open" : "В момента са отворени",
-    "Wrong username or password." : "Грешен потребител или парола",
-    "User disabled" : "Потребителят е деактивиран",
-    "Username or email" : "Потребител или имейл",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ако този профил съществува, на неговия имейл адрес е изпратено съобщение за възстановяване на паролата. Ако не го получите, проверете имейл адреса си и/или името на профила, проверете папките за нежелана поща/спам или потърсете помощ от местната администрация.",
-    "Error loading message template: {error}" : "Грешка при зареждането на шаблона за съобщения: {error}",
-    "Users" : "Потребители",
-    "Username" : "Потребител",
-    "Database user" : "Потребител за базата данни",
-    "This action requires you to confirm your password" : "Необходимо е да потвърдите паролата си",
-    "Confirm your password" : "Потвърдете паролата си",
-    "Confirm" : "Потвърди",
-    "App token" : "Парола за приложението",
-    "Alternative log in using app token" : "Алтернативен метод за вписване с парола за приложение",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Моля, използвайте актуализатора на командния ред, защото имате голям екземпляр с повече от 50 потребители."
+    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
+    "You have not added any info yet" : "Все още не сте добавили никаква информация",
+    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
+    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
+    "Edit Profile" : "Редактиране на профил",
+    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
+    "Very weak password" : "Много проста парола",
+    "Weak password" : "Проста парола",
+    "So-so password" : "Не особено добра парола",
+    "Good password" : "Добра парола",
+    "Strong password" : "Сложна парола",
+    "Profile not found" : "Профилът не е намерен",
+    "The profile does not exist." : "Профилът не съществува.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Създай администраторски профил</strong>",
+    "New admin account name" : "Ново име на администраторския профил",
+    "Show password" : "Покажи парола",
+    "Toggle password visibility" : "Превключване на видимостта на парола",
+    "Configure the database" : "Конфигуриране на базата данни",
+    "Only %s is available." : "Само %s е наличен.",
+    "Database account" : "Профил за база данни",
+    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда"
 },
 "nplurals=2; plural=(n != 1);");
