@@ -52,6 +52,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Изображението на аватара не е квадратно",
     "Files" : "Файлове",
     "View profile" : "Преглед на профил",
+    "_%nh_::_%nh_" : ["%nч","%nч"],
     "Local time: %s" : "Местно време: %s",
     "today" : "днес",
     "tomorrow" : "утре",
@@ -91,6 +92,7 @@ OC.L10N.register(
     "Administration settings" : "Административни настройки",
     "Settings" : "Настройки",
     "Log out" : "Отписване",
+    "Accounts" : "Профили",
     "Email" : "Имейл",
     "Mail %s" : "Поща %s",
     "Fediverse" : "Fediverse /съвкупност от обединени сървъри/",
@@ -102,18 +104,18 @@ OC.L10N.register(
     "Website" : "Уеб сайт",
     "Visit %s" : "Посещение %s",
     "Address" : "Адрес",
-    "Profile picture" : "Снимка на профила",
+    "Profile picture" : "Профилна снимка",
     "About" : "Относно",
     "Display name" : "Име за визуализация",
     "Headline" : "Заглавие",
-    "Organisation" : "Организация",
+    "Organization" : "Организиране",
     "Role" : "Роля",
+    "Pronouns" : "Обръщение",
     "Additional settings" : "Допълнителни настройки",
     "Enter the database name for %s" : "Въведете името на базата данни за %s",
     "You cannot use dots in the database name %s" : "Не можете да използвате точки в името на базата данни %s",
     "You need to enter details of an existing account." : "Трябва да въведете подробности за съществуващ профил.",
     "Oracle connection could not be established" : "Не можа да се установи връзка с Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
@@ -122,14 +124,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
     "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
     "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
-    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« с вас",
-    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« с вас.",
-    "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
-    "Open »%s«" : "Отвори »%s«",
     "%1$s via %2$s" : "%1$s чрез %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s сподели »%2$s« с вас и иска да добави:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s сподели »%2$s« с вас и иска да добави",
-    "»%s« added a note to a file shared with you" : "»%s« добави бележка към файл, споделен с вас ",
     "Unknown share type" : "Неизвестен тип споделяне",
     "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
     "Cannot increase permissions of %s" : "Не могат да се увеличат права на %s",
@@ -190,8 +185,6 @@ OC.L10N.register(
     "Login canceled by app" : "Вписването е отказано от приложението",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложението „%1$s“ не може да бъде инсталирано, защото следните зависимости не са изпълнени: %2$s",
     "a safe home for all your data" : "безопасен дом за всички ваши данни",
-    "File is currently busy, please try again later" : "Файлът в момента е зает, моля, опитайте отново по-късно",
-    "Cannot download file" : "Файлът не можа да бъде изтеглен",
     "Application is not enabled" : "Приложението не е включено",
     "Authentication error" : "Грешка при удостоверяването",
     "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
@@ -199,20 +192,16 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не може да се пише в \"config\" директория.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията. Погледнете %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Но ако предпочитате да запазите файла config.php само за четене, задайте опцията \"config_is_read_only\" на true/вярно/ в него. Погледнете %s",
-    "Cannot write into \"apps\" directory." : "Не може да се пише в \"apps\" директория.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като се даде достъп на уеб сървъра да записва в app директорията или като изключи приложението магазин за приложения в config файла.",
     "Cannot create \"data\" directory." : "Неможе да се създаде \"data\" директория с данни.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в основната директория. Погледнете %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Права обикновено могат да бъдат оправени когато се даде достъп на уеб сървъра да пише в основната директория. Погледнете %s.",
     "Your data directory is not writable." : "Вашата директория с данни не е записваема.",
-    "Setting locale to %s failed." : "Неуспешно задаване на езикова променлива %s.",
-    "Please install one of these locales on your system and restart your web server." : "Моля, инсталирайте една от тези езикови променливи на вашата система и си рестартирайте уеб сървъра.",
+    "Setting locale to %s failed." : "Неуспешно задаване на регион %s. ",
+    "Please install one of these locales on your system and restart your web server." : "Моля, задайте един от следните региони във Вашата система след което рестартирайте сървъра.",
     "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
     "Please ask your server administrator to install the module." : "Моля, помолете вашия администратор да инсталира модула.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP настройка \"%s\" не е зададена на \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Регулирането на тази настройка в php.ini ще накара Nextcloud да работи отново",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е настроен на <code>%s</code> вместо очакваната стойност <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
@@ -233,38 +222,21 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка при свързването с хранилище. %s",
     "Storage is temporarily not available" : "Временно хранилището не е налично",
     "Storage connection timeout. %s" : "Време за изчакване при свързването с хранилище. %s",
+    "Images" : "Изображения",
+    "Question" : "Въпрос",
+    "Confirmation" : "Потвърждение",
     "Prompt" : "Подкана",
+    "Text" : "Текст",
     "Summary" : "Резюме",
     "Translate" : "Превод",
     "Target language" : "Целеви език",
     "Result" : "Резултат",
-    "Education Edition" : "Образователно издание",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Влезлият потребител трябва да е администратор, подадминистратор или да е получил специално право за достъп до тази настройка",
-    "Logged in user must be an admin or sub admin" : "Влезлият потребител трябва да е администратор или подадминистратор ",
-    "Logged in user must be an admin" : "Влезлият потребител трябва да е администратор",
-    "File name is a reserved word" : "Името на файла е запазена дума",
-    "File name contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
-    "File name is too long" : "Името на файла е твърде дълго",
-    "Help" : "Помощ",
-    "Users" : "Потребители",
-    "Unknown user" : "Непознат потребител",
-    "Enter the database username and name for %s" : "Въведете името на потребител на базата данни и име за %s",
-    "Enter the database username for %s" : "Въведете името на потребител на базата данни за %s",
-    "MySQL username and/or password not valid" : "Име на потребител и/или паролата на MySQL не са валидни",
-    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
-    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
-    "Set an admin username." : "Задайте потребителско име за администратор.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Неуспешно споделяне на %s, защото този елемент вече е споделен с потребителя %s",
-    "The username is already being used" : "Потребителското име е вече заето.",
-    "Could not create user" : "Неуспешно създаване на потребител",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Потребителските имена може да съдържат само следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
-    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
-    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
-    "Username must not consist of dots only" : "Името на потребител не трябва да се състои само от точки",
-    "Username is invalid because files already exist for this user" : "Името на потребител е невалидно, тъй като файловете вече съществуват за този потребител",
-    "User disabled" : "Потребителят е деактивиран",
-    "Your data directory is readable by other users." : "Вашата директория с данни може да се чете от други потребители.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверете се, че има файл, наречен \".ocdata\" в корена на директорията с данни."
+    "Organisation" : "Организация",
+    "File is currently busy, please try again later" : "Файлът в момента е зает, моля, опитайте отново по-късно",
+    "Cannot download file" : "Файлът не можа да бъде изтеглен",
+    "Cannot write into \"apps\" directory." : "Не може да се пише в \"apps\" директория.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като се даде достъп на уеб сървъра да записва в app директорията или като изключи приложението магазин за приложения в config файла.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е настроен на <code>%s</code> вместо очакваната стойност <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini."
 },
 "nplurals=2; plural=(n != 1);");
