@@ -14,6 +14,7 @@ use Exception;
 use InvalidArgumentException;
 use OC\Authentication\Token\PublicKeyTokenProvider;
 use OC\Authentication\Token\TokenCleanupJob;
+use OC\Core\BackgroundJobs\GenerateMetadataJob;
 use OC\Log\Rotate;
 use OC\Preview\BackgroundCleanupJob;
 use OC\TextProcessing\RemoveOldTasksBackgroundJob;
@@ -148,7 +149,7 @@ class Setup {
 	 * a few system checks.
 	 *
 	 * @return array of system info, including an "errors" value
-	 * in case of errors/warnings
+	 *               in case of errors/warnings
 	 */
 	public function getSystemInfo(bool $allowAllDatabases = false): array {
 		$databases = $this->getSupportedDatabases($allowAllDatabases);
@@ -185,7 +186,7 @@ class Setup {
 			$errors[] = [
 				'error' => $this->l10n->t(
 					'Mac OS X is not supported and %s will not work properly on this platform. ' .
-					'Use it at your own risk! ',
+					'Use it at your own risk!',
 					[$this->defaults->getProductName()]
 				),
 				'hint' => $this->l10n->t('For the best results, please consider using a GNU/Linux server instead.'),
@@ -231,7 +232,7 @@ class Setup {
 			$error[] = $l->t('Set an admin password.');
 		}
 		if (empty($options['directory'])) {
-			$options['directory'] = \OC::$SERVERROOT . "/data";
+			$options['directory'] = \OC::$SERVERROOT . '/data';
 		}
 
 		if (!isset(self::$dbSetupClasses[$dbType])) {
@@ -249,7 +250,7 @@ class Setup {
 
 		// validate the data directory
 		if ((!is_dir($dataDir) && !mkdir($dataDir)) || !is_writable($dataDir)) {
-			$error[] = $l->t("Cannot create or write into the data directory %s", [$dataDir]);
+			$error[] = $l->t('Cannot create or write into the data directory %s', [$dataDir]);
 		}
 
 		if (!empty($error)) {
@@ -341,7 +342,7 @@ class Setup {
 		}
 
 		$config = Server::get(IConfig::class);
-		$config->setAppValue('core', 'installedat', (string)microtime(true));
+		$config->setAppValue('core', 'installedat', (string) microtime(true));
 		$appConfig = Server::get(IAppConfig::class);
 		$appConfig->setValueInt('core', 'lastupdatedat', time());
 
@@ -393,7 +394,7 @@ class Setup {
 		$userSession->login($username, $password);
 		$user = $userSession->getUser();
 		if (!$user) {
-			$error[] = "No account found in session.";
+			$error[] = 'No account found in session.';
 			return $error;
 		}
 		$userSession->createSessionToken($request, $user->getUID(), $username, $password);
@@ -416,6 +417,7 @@ class Setup {
 		$jobList->add(BackgroundCleanupJob::class);
 		$jobList->add(RemoveOldTasksBackgroundJob::class);
 		$jobList->add(CleanupDeletedUsers::class);
+		$jobList->add(GenerateMetadataJob::class);
 	}
 
 	/**
@@ -510,12 +512,12 @@ class Setup {
 		if (function_exists('disk_free_space')) {
 			$df = disk_free_space(\OC::$SERVERROOT);
 			$size = strlen($content) + 10240;
-			if ($df !== false && $df < (float)$size) {
-				throw new \Exception(\OC::$SERVERROOT . " does not have enough space for writing the htaccess file! Not writing it back!");
+			if ($df !== false && $df < (float) $size) {
+				throw new \Exception(\OC::$SERVERROOT . ' does not have enough space for writing the htaccess file! Not writing it back!');
 			}
 		}
 		//suppress errors in case we don't have permissions for it
-		return (bool)@file_put_contents($setupHelper->pathToHtaccess(), $htaccessContent . $content . "\n");
+		return (bool) @file_put_contents($setupHelper->pathToHtaccess(), $htaccessContent . $content . "\n");
 	}
 
 	public static function protectDataDirectory(): void {
@@ -544,7 +546,7 @@ class Setup {
 		$content .= "# Section for Apache 2.2 to 2.6\n";
 		$content .= "<IfModule mod_autoindex.c>\n";
 		$content .= "  IndexIgnore *\n";
-		$content .= "</IfModule>";
+		$content .= '</IfModule>';
 
 		$baseDir = Server::get(IConfig::class)->getSystemValueString('datadirectory', \OC::$SERVERROOT . '/data');
 		file_put_contents($baseDir . '/.htaccess', $content);
@@ -557,8 +559,8 @@ class Setup {
 		/** @var mixed $vendor */
 		/** @var mixed $OC_Channel */
 		return [
-			'vendor' => (string)$vendor,
-			'channel' => (string)$OC_Channel,
+			'vendor' => (string) $vendor,
+			'channel' => (string) $OC_Channel,
 		];
 	}
 
